@@ -30,7 +30,6 @@
 
 Covers the ``blastxml`` format and the BLAST databases.
 """
-import io
 import logging
 import os
 from time import sleep
@@ -148,7 +147,7 @@ class BlastXml(GenericXml):
                         raise ValueError("The header in BLAST XML file %s is too long" % f)
                 if "<BlastOutput>" not in header:
                     h.close()
-                    raise ValueError("%s is not a BLAST XML file:\n%s\n..." % (f, header))
+                    raise ValueError("{} is not a BLAST XML file:\n{}\n...".format(f, header))
                 if f == split_files[0]:
                     out.write(header)
                     old_header = header
@@ -197,14 +196,14 @@ class _BlastDb(Data):
         If preview is `False` triggers download.
         """
         if not preview:
-            return super(_BlastDb, self).display_data(trans,
-                                                      data=data,
-                                                      preview=preview,
-                                                      filename=filename,
-                                                      to_ext=to_ext,
-                                                      size=size,
-                                                      offset=offset,
-                                                      **kwd)
+            return super().display_data(trans,
+                                        data=data,
+                                        preview=preview,
+                                        filename=filename,
+                                        to_ext=to_ext,
+                                        size=size,
+                                        offset=offset,
+                                        **kwd)
         if self.file_ext == "blastdbn":
             title = "This is a nucleotide BLAST database"
         elif self.file_ext == "blastdbp":
@@ -217,14 +216,14 @@ class _BlastDb(Data):
         msg = ""
         try:
             # Try to use any text recorded in the dummy index file:
-            with io.open(data.file_name, "rU", encoding='utf-8') as handle:
+            with open(data.file_name, encoding='utf-8') as handle:
                 msg = handle.read().strip()
         except Exception:
             pass
         if not msg:
             msg = title
         # Galaxy assumes HTML for the display of composite datatypes,
-        return smart_str("<html><head><title>%s</title></head><body><pre>%s</pre></body></html>" % (title, msg))
+        return smart_str("<html><head><title>{}</title></head><body><pre>{}</pre></body></html>".format(title, msg))
 
     def merge(split_files, output_file):
         """Merge BLAST databases (not implemented for now)."""
@@ -307,3 +306,108 @@ class BlastDomainDb(_BlastDb, Data):
         self.add_composite_file('blastdb.psi', is_binary=True, optional=True)
         self.add_composite_file('blastdb.rps', is_binary=True, optional=True)
         self.add_composite_file('blastdb.aux', is_binary=True, optional=True)
+
+
+class LastDb(Data):
+    """Class for LAST database files."""
+    file_ext = 'lastdb'
+    allow_datatype_change = False
+    composite_type = 'basic'
+
+    def set_peek(self, dataset, is_multi_byte=False):
+        """Set the peek and blurb text."""
+        if not dataset.dataset.purged:
+            dataset.peek = "LAST database (multiple files)"
+            dataset.blurb = "LAST database (multiple files)"
+        else:
+            dataset.peek = 'file does not exist'
+            dataset.blurb = 'file purged from disk'
+
+    def display_peek(self, dataset):
+        """Create HTML content, used for displaying peek."""
+        try:
+            return dataset.peek
+        except Exception:
+            return "LAST database (multiple files)"
+
+    def __init__(self, **kwd):
+        Data.__init__(self, **kwd)
+        self.add_composite_file('lastdb.bck', is_binary=True)
+        self.add_composite_file('lastdb.des', description="Description file", is_binary=False)
+        self.add_composite_file('lastdb.prj', description="Project resume file", is_binary=False)
+        self.add_composite_file('lastdb.sds', is_binary=True)
+        self.add_composite_file('lastdb.ssp', is_binary=True)
+        self.add_composite_file('lastdb.suf', is_binary=True)
+        self.add_composite_file('lastdb.tis', is_binary=True)
+
+
+class BlastNucDb5(_BlastDb, Data):
+    """Class for nucleotide BLAST database files."""
+    file_ext = 'blastdbn5'
+    allow_datatype_change = False
+    composite_type = 'basic'
+
+    def __init__(self, **kwd):
+        Data.__init__(self, **kwd)
+        self.add_composite_file('blastdb.nhr', is_binary=True)  # sequence headers
+        self.add_composite_file('blastdb.nin', is_binary=True)  # index file
+        self.add_composite_file('blastdb.nsq', is_binary=True)  # nucleotide sequences
+        self.add_composite_file('blastdb.nal', is_binary=False, optional=True)  # alias ( -gi_mask option of makeblastdb)
+        self.add_composite_file('blastdb.nhd', is_binary=True, optional=True)  # sorted sequence hash values ( -hash_index option of makeblastdb)
+        self.add_composite_file('blastdb.nhi', is_binary=True, optional=True)  # index of sequence hash values ( -hash_index option of makeblastdb)
+        self.add_composite_file('blastdb.nnd', is_binary=True, optional=True)  # sorted GI values ( -parse_seqids option of makeblastdb and gi present in the description lines)
+        self.add_composite_file('blastdb.nni', is_binary=True, optional=True)  # index of GI values ( -parse_seqids option of makeblastdb and gi present in the description lines)
+        self.add_composite_file('blastdb.nog', is_binary=True, optional=True)  # OID->GI lookup file ( -hash_index or -parse_seqids option of makeblastdb)
+        self.add_composite_file('blastdb.nsd', is_binary=True, optional=True)  # sorted sequence accession values ( -hash_index or -parse_seqids option of makeblastdb)
+        self.add_composite_file('blastdb.nsi', is_binary=True, optional=True)  # index of sequence accession values ( -hash_index or -parse_seqids option of makeblastdb)
+#        self.add_composite_file('blastdb.00.idx', is_binary=True, optional=True)  # first volume of the MegaBLAST index generated by makembindex
+# The previous line should be repeated for each index volume, with filename extensions like '.01.idx', '.02.idx', etc.
+        self.add_composite_file('blastdb.shd', is_binary=True, optional=True)  # MegaBLAST index superheader (-old_style_index false option of makembindex)
+#        self.add_composite_file('blastdb.naa', is_binary=True, optional=True)  # index of a WriteDB column for e.g. mask data
+#        self.add_composite_file('blastdb.nab', is_binary=True, optional=True)  # data of a WriteDB column
+#        self.add_composite_file('blastdb.nac', is_binary=True, optional=True)  # multiple byte order for a WriteDB column
+# The previous 3 lines should be repeated for each WriteDB column, with filename extensions like ('.nba', '.nbb', '.nbc'), ('.nca', '.ncb', '.ncc'), etc.
+
+
+class BlastProtDb5(_BlastDb, Data):
+    """Class for protein BLAST database files."""
+    file_ext = 'blastdbp5'
+    allow_datatype_change = False
+    composite_type = 'basic'
+
+    def __init__(self, **kwd):
+        Data.__init__(self, **kwd)
+# Component file comments are as in BlastNucDb except where noted
+        self.add_composite_file('blastdb.phr', is_binary=True)
+        self.add_composite_file('blastdb.pin', is_binary=True)
+        self.add_composite_file('blastdb.psq', is_binary=True)  # protein sequences
+        self.add_composite_file('blastdb.phd', is_binary=True, optional=True)
+        self.add_composite_file('blastdb.phi', is_binary=True, optional=True)
+        self.add_composite_file('blastdb.pnd', is_binary=True, optional=True)
+        self.add_composite_file('blastdb.pni', is_binary=True, optional=True)
+        self.add_composite_file('blastdb.pog', is_binary=True, optional=True)
+        self.add_composite_file('blastdb.psd', is_binary=True, optional=True)
+        self.add_composite_file('blastdb.psi', is_binary=True, optional=True)
+#        self.add_composite_file('blastdb.paa', is_binary=True, optional=True)
+#        self.add_composite_file('blastdb.pab', is_binary=True, optional=True)
+#        self.add_composite_file('blastdb.pac', is_binary=True, optional=True)
+# The last 3 lines should be repeated for each WriteDB column, with filename extensions like ('.pba', '.pbb', '.pbc'), ('.pca', '.pcb', '.pcc'), etc.
+
+
+class BlastDomainDb5(_BlastDb, Data):
+    """Class for domain BLAST database files."""
+    file_ext = 'blastdbd5'
+    allow_datatype_change = False
+    composite_type = 'basic'
+
+    def __init__(self, **kwd):
+        Data.__init__(self, **kwd)
+        self.add_composite_file('blastdb.phr', is_binary=True)
+        self.add_composite_file('blastdb.pin', is_binary=True)
+        self.add_composite_file('blastdb.psq', is_binary=True)
+        self.add_composite_file('blastdb.freq', is_binary=True, optional=True)
+        self.add_composite_file('blastdb.loo', is_binary=True, optional=True)
+        self.add_composite_file('blastdb.psd', is_binary=True, optional=True)
+        self.add_composite_file('blastdb.psi', is_binary=True, optional=True)
+        self.add_composite_file('blastdb.rps', is_binary=True, optional=True)
+        self.add_composite_file('blastdb.aux', is_binary=True, optional=True)
