@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-from __future__ import print_function
 
 import sys
 
@@ -30,15 +29,17 @@ def main():
     with open(input_fname) as in_file, open(sys.argv[2], 'w') as out_file:
         out_file.write('{"sections" : [')
 
-        for line in in_file:
+        line = in_file.readline()
+        while line:
             current_line += 1
             if 0 == current_line % lines_per_chunk:
                 chunk_end = in_file.tell()
-                out_file.write('{"start":"%s","end":"%s","sequences":"%s"},' % (chunk_begin, chunk_end, sequences))
+                out_file.write('{{"start":"{}","end":"{}","sequences":"{}"}},'.format(chunk_begin, chunk_end, sequences))
                 chunk_begin = chunk_end
+            line = in_file.readline()
 
         chunk_end = in_file.tell()
-        out_file.write('{"start":"%s","end":"%s","sequences":"%s"}' % (chunk_begin, chunk_end, (current_line % lines_per_chunk) / 4))
+        out_file.write('{{"start":"{}","end":"{}","sequences":"{}"}}'.format(chunk_begin, chunk_end, (current_line % lines_per_chunk) / 4))
         out_file.write(']}\n')
 
 
