@@ -1,5 +1,3 @@
-from __future__ import absolute_import
-
 import abc
 import logging
 import mimetypes
@@ -11,7 +9,6 @@ import zipfile
 from collections import OrderedDict
 from inspect import isclass
 
-import six
 import webob.exc
 from markupsafe import escape
 
@@ -49,7 +46,7 @@ DOWNLOAD_FILENAME_PATTERN_COLLECTION_ELEMENT = "Galaxy${hdca_hid}-[${hdca_name}_
 DEFAULT_MAX_PEEK_SIZE = 1000000  # 1 MB
 
 
-class DatatypeValidation(object):
+class DatatypeValidation:
 
     def __init__(self, state, message):
         self.state = state
@@ -68,7 +65,7 @@ class DatatypeValidation(object):
         return DatatypeValidation("unknown", "Dataset validation unimplemented for this datatype.")
 
     def __repr__(self):
-        return "DatatypeValidation[state=%s,message=%s]" % (self.state, self.message)
+        return "DatatypeValidation[state={},message={}]".format(self.state, self.message)
 
 
 def validate(dataset_instance):
@@ -91,9 +88,8 @@ class DataMeta(abc.ABCMeta):
         metadata.Statement.process(cls)
 
 
-@six.add_metaclass(DataMeta)
 @dataproviders.decorators.has_dataproviders
-class Data(object):
+class Data(metaclass=DataMeta):
     """
     Base class for all datatypes.  Implements basic interfaces as well
     as class methods for metadata.
@@ -163,7 +159,6 @@ class Data(object):
 
     def groom_dataset_content(self, file_name):
         """This function is called on an output dataset file if dataset_content_needs_grooming returns True."""
-        pass
 
     def init_meta(self, dataset, copy_from=None):
         # Metadata should be left mostly uninitialized.  Dataset will
@@ -259,91 +254,85 @@ class Data(object):
         archname = '%s.html' % display_name  # fake the real nature of the html file
         try:
             archive.add(data_filename, archname)
-        except IOError:
+        except OSError:
             error = True
             log.exception("Unable to add composite parent %s to temporary library download archive", data_filename)
             msg = "Unable to create archive for download, please report this error"
             messagetype = "error"
         return error, msg, messagetype
 
-    def _archive_composite_dataset(self, trans, data=None, **kwd):
+    def _archive_composite_dataset(self, trans, data, do_action='zip'):
         # save a composite object into a compressed archive for downloading
-        params = util.Params(kwd)
         outfname = data.name[0:150]
         outfname = ''.join(c in FILENAME_VALID_CHARS and c or '_' for c in outfname)
-        if params.do_action is None:
-            params.do_action = 'zip'  # default
-        msg = util.restore_text(params.get('msg', ''))
-        if not data:
-            msg = "You must select at least one dataset"
-        else:
-            error = False
-            try:
-                if params.do_action == 'zip':
-                    # Can't use mkstemp - the file must not exist first
-                    tmpd = tempfile.mkdtemp(dir=trans.app.config.new_file_path, prefix='gx_composite_archive_')
-                    util.umask_fix_perms(tmpd, trans.app.config.umask, 0o777, trans.app.config.gid)
-                    tmpf = os.path.join(tmpd, 'library_download.' + params.do_action)
-                    archive = zipfile.ZipFile(tmpf, 'w', zipfile.ZIP_DEFLATED, True)
+        error = False
+        msg = ''
+        try:
+            if do_action == 'zip':
+                # Can't use mkstemp - the file must not exist first
+                tmpd = tempfile.mkdtemp(dir=trans.app.config.new_file_path, prefix='gx_composite_archive_')
+                util.umask_fix_perms(tmpd, trans.app.config.umask, 0o777, trans.app.config.gid)
+                tmpf = os.path.join(tmpd, 'library_download.' + do_action)
+                archive = zipfile.ZipFile(tmpf, 'w', zipfile.ZIP_DEFLATED, True)
 
-                    def zipfile_add(fpath, arcname):
-                        encoded_arcname = arcname.encode('CP437')
-                        try:
-                            archive.write(fpath, encoded_arcname)
-                        except TypeError:
-                            # Despite documenting the need for CP437 encoded arcname,
-                            # python 3 actually needs this to be a unicode string ...
-                            # https://bugs.python.org/issue24110
-                            archive.write(fpath, arcname)
+                def zipfile_add(fpath, arcname):
+                    encoded_arcname = arcname.encode('CP437')
+                    try:
+                        archive.write(fpath, encoded_arcname)
+                    except TypeError:
+                        # Despite documenting the need for CP437 encoded arcname,
+                        # python 3 actually needs this to be a unicode string ...
+                        # https://bugs.python.org/issue24110
+                        archive.write(fpath, arcname)
 
-                    archive.add = zipfile_add
+                archive.add = zipfile_add
 
-                elif params.do_action == 'tgz':
-                    archive = util.streamball.StreamBall('w|gz')
-                elif params.do_action == 'tbz':
-                    archive = util.streamball.StreamBall('w|bz2')
-            except (OSError, zipfile.BadZipFile):
-                error = True
-                log.exception("Unable to create archive for download")
-                msg = "Unable to create archive for %s for download, please report this error" % outfname
+            elif do_action == 'tgz':
+                archive = util.streamball.StreamBall('w|gz')
+            elif do_action == 'tbz':
+                archive = util.streamball.StreamBall('w|bz2')
+        except (OSError, zipfile.BadZipFile):
+            error = True
+            log.exception("Unable to create archive for download")
+            msg = "Unable to create archive for %s for download, please report this error" % outfname
+        if not error:
+            ext = data.extension
+            path = data.file_name
+            efp = data.extra_files_path
+            # Add any central file to the archive,
+
+            display_name = os.path.splitext(outfname)[0]
+            if not display_name.endswith(ext):
+                display_name = '{}_{}'.format(display_name, ext)
+
+            error, msg = self._archive_main_file(archive, display_name, path)[:2]
             if not error:
-                ext = data.extension
-                path = data.file_name
-                efp = data.extra_files_path
-                # Add any central file to the archive,
-
-                display_name = os.path.splitext(outfname)[0]
-                if not display_name.endswith(ext):
-                    display_name = '%s_%s' % (display_name, ext)
-
-                error, msg = self._archive_main_file(archive, display_name, path)[:2]
-                if not error:
-                    # Add any child files to the archive,
-                    for fpath, rpath in self.__archive_extra_files_path(extra_files_path=efp):
-                        try:
-                            archive.add(fpath, rpath)
-                        except IOError:
-                            error = True
-                            log.exception("Unable to add %s to temporary library download archive", rpath)
-                            msg = "Unable to create archive for download, please report this error"
-                            continue
-                if not error:
-                    if params.do_action == 'zip':
-                        archive.close()
-                        tmpfh = open(tmpf, 'rb')
-                        # CANNOT clean up - unlink/rmdir was always failing because file handle retained to return - must rely on a cron job to clean up tmp
-                        trans.response.set_content_type("application/x-zip-compressed")
-                        trans.response.headers["Content-Disposition"] = 'attachment; filename="%s.zip"' % outfname
-                        return tmpfh
-                    else:
-                        trans.response.set_content_type("application/x-tar")
-                        outext = 'tgz'
-                        if params.do_action == 'tbz':
-                            outext = 'tbz'
-                        trans.response.headers["Content-Disposition"] = 'attachment; filename="%s.%s"' % (outfname, outext)
-                        archive.wsgi_status = trans.response.wsgi_status()
-                        archive.wsgi_headeritems = trans.response.wsgi_headeritems()
-                        return archive.stream
+                # Add any child files to the archive,
+                for fpath, rpath in self.__archive_extra_files_path(extra_files_path=efp):
+                    try:
+                        archive.add(fpath, rpath)
+                    except OSError:
+                        error = True
+                        log.exception("Unable to add %s to temporary library download archive", rpath)
+                        msg = "Unable to create archive for download, please report this error"
+                        continue
+            if not error:
+                if do_action == 'zip':
+                    archive.close()
+                    tmpfh = open(tmpf, 'rb')
+                    # CANNOT clean up - unlink/rmdir was always failing because file handle retained to return - must rely on a cron job to clean up tmp
+                    trans.response.set_content_type("application/x-zip-compressed")
+                    trans.response.headers["Content-Disposition"] = 'attachment; filename="%s.zip"' % outfname
+                    return tmpfh
+                else:
+                    trans.response.set_content_type("application/x-tar")
+                    outext = 'tgz'
+                    if do_action == 'tbz':
+                        outext = 'tbz'
+                    trans.response.headers["Content-Disposition"] = 'attachment; filename="{}.{}"'.format(outfname, outext)
+                    archive.wsgi_status = trans.response.wsgi_status()
+                    archive.wsgi_headeritems = trans.response.wsgi_headeritems()
+                    return archive.stream
         return trans.show_error_message(msg)
 
     def __archive_extra_files_path(self, extra_files_path):
@@ -357,7 +346,7 @@ class Data(object):
     def _serve_raw(self, trans, dataset, to_ext, **kwd):
         trans.response.headers['Content-Length'] = int(os.stat(dataset.file_name).st_size)
         trans.response.set_content_type("application/octet-stream")  # force octet-stream so Safari doesn't append mime extensions to filename
-        filename = self._download_filename(dataset, to_ext, hdca=kwd.get("hdca", None), element_identifier=kwd.get("element_identifier", None))
+        filename = self._download_filename(dataset, to_ext, hdca=kwd.get("hdca"), element_identifier=kwd.get("element_identifier"))
         trans.response.headers["Content-Disposition"] = 'attachment; filename="%s"' % filename
         return open(dataset.file_name, mode='rb')
 
@@ -374,14 +363,14 @@ class Data(object):
         rel_paths = []
         file_paths = []
         if dataset.extension in composite_extensions:
-            main_file = "%s.%s" % (name, 'html')
+            main_file = "{}.{}".format(name, 'html')
             rel_paths.append(main_file)
             file_paths.append(dataset.file_name)
             for fpath, rpath in self.__archive_extra_files_path(dataset.extra_files_path):
                 rel_paths.append(os.path.join(name, rpath))
                 file_paths.append(fpath)
         else:
-            rel_paths.append("%s.%s" % (name or dataset.file_name, dataset.extension))
+            rel_paths.append("{}.{}".format(name or dataset.file_name, dataset.extension))
             file_paths.append(dataset.file_name)
         return zip(file_paths, rel_paths)
 
@@ -401,7 +390,7 @@ class Data(object):
         # Prevent IE8 from sniffing content type since we're explicit about it.  This prevents intentionally text/plain
         # content from being rendered in the browser
         trans.response.headers['X-Content-Type-Options'] = 'nosniff'
-        if isinstance(data, six.string_types):
+        if isinstance(data, str):
             return smart_str(data)
         if filename and filename != "index":
             # For files in extra_files_path
@@ -427,7 +416,7 @@ class Data(object):
                             # href = url_for(controller='dataset', action='display',
                             # dataset_id=trans.security.encode_id(data.dataset.id),
                             # preview=preview, filename=fname, to_ext=to_ext)
-                            tmp_fh.write('<tr bgcolor="%s"><td>%s</td></tr>\n' % (bgcolor, escape(fname)))
+                            tmp_fh.write('<tr bgcolor="{}"><td>{}</td></tr>\n'.format(bgcolor, escape(fname)))
                         tmp_fh.write('</table></body></html>\n')
                     return self._yield_user_file_content(trans, data, tmp_file_name)
                 mime = mimetypes.guess_type(file_path)[0]
@@ -439,17 +428,17 @@ class Data(object):
                 self._clean_and_set_mime_type(trans, mime)
                 return self._yield_user_file_content(trans, data, file_path)
             else:
-                return webob.exc.HTTPNotFound("Could not find '%s' on the extra files path %s." % (filename, file_path))
+                return webob.exc.HTTPNotFound("Could not find '{}' on the extra files path {}.".format(filename, file_path))
         self._clean_and_set_mime_type(trans, data.get_mime())
 
         trans.log_event("Display dataset id: %s" % str(data.id))
         from galaxy import datatypes  # DBTODO REMOVE THIS AT REFACTOR
         if to_ext or isinstance(data.datatype, datatypes.binary.Binary):  # Saving the file, or binary file
             if data.extension in composite_extensions:
-                return self._archive_composite_dataset(trans, data, **kwd)
+                return self._archive_composite_dataset(trans, data, do_action=kwd.get('do_action', 'zip'))
             else:
                 trans.response.headers['Content-Length'] = int(os.stat(data.file_name).st_size)
-                filename = self._download_filename(data, to_ext, hdca=kwd.get("hdca", None), element_identifier=kwd.get("element_identifier", None))
+                filename = self._download_filename(data, to_ext, hdca=kwd.get("hdca"), element_identifier=kwd.get("element_identifier"))
                 trans.response.set_content_type("application/octet-stream")  # force octet-stream so Safari doesn't append mime extensions to filename
                 trans.response.headers["Content-Disposition"] = 'attachment; filename="%s"' % filename
                 return open(data.file_name, 'rb')
@@ -488,7 +477,8 @@ class Data(object):
         if self.is_binary:
             result = "*cannot display binary content*\n"
         else:
-            contents = open(dataset_instance.file_name, "r").read(DEFAULT_MAX_PEEK_SIZE)
+            with open(dataset_instance.file_name) as f:
+                contents = f.read(DEFAULT_MAX_PEEK_SIZE)
             result = markdown_format_helpers.literal_via_fence(contents)
             if len(contents) == DEFAULT_MAX_PEEK_SIZE:
                 result += markdown_format_helpers.indicate_data_truncated()
@@ -498,15 +488,16 @@ class Data(object):
         """This method is responsible for sanitizing the HTML if needed."""
         if trans.app.config.sanitize_all_html and trans.response.get_content_type() == "text/html":
             # Sanitize anytime we respond with plain text/html content.
-            # Check to see if this dataset's parent job is whitelisted
+            # Check to see if this dataset's parent job is allowlisted
             # We cannot currently trust imported datasets for rendering.
-            if not from_dataset.creating_job.imported and from_dataset.creating_job.tool_id in trans.app.config.sanitize_whitelist:
+            if not from_dataset.creating_job.imported and from_dataset.creating_job.tool_id in trans.app.config.sanitize_allowlist:
                 return open(filename, mode='rb')
 
             # This is returning to the browser, it needs to be encoded.
             # TODO Ideally this happens a layer higher, but this is a bad
             # issue affecting many tools
-            return sanitize_html(open(filename, 'r').read()).encode('utf-8')
+            with open(filename) as f:
+                return sanitize_html(f.read()).encode('utf-8')
 
         return open(filename, mode='rb')
 
@@ -626,7 +617,7 @@ class Data(object):
                 return getattr(self, self.supported_display_apps[type]['file_function'])(dataset, **kwd)
         except Exception:
             log.exception('Function %s is referred to in datatype %s for displaying as type %s, but is not accessible', self.supported_display_apps[type]['file_function'], self.__class__.__name__, type)
-        return "This display type (%s) is not implemented for this datatype (%s)." % (type, dataset.ext)
+        return "This display type ({}) is not implemented for this datatype ({}).".format(type, dataset.ext)
 
     def get_display_links(self, dataset, type, app, base_url, target_frame='_blank', **kwd):
         """
@@ -648,7 +639,7 @@ class Data(object):
         return datatypes_registry.get_converters_by_datatype(original_dataset.ext)
 
     def find_conversion_destination(self, dataset, accepted_formats, datatypes_registry, **kwd):
-        """Returns ( target_ext, existing converted dataset )"""
+        """Returns ( direct_match, converted_ext, existing converted dataset )"""
         return datatypes_registry.find_conversion_destination_for_dataset_by_extensions(dataset, accepted_formats, **kwd)
 
     def convert_dataset(self, trans, original_dataset, target_type, return_output=False, visible=True, deps=None, target_context=None, history=None):
@@ -656,7 +647,7 @@ class Data(object):
         converter = trans.app.datatypes_registry.get_converter_by_target_type(original_dataset.ext, target_type)
 
         if converter is None:
-            raise Exception("A converter does not exist for %s to %s." % (original_dataset.ext, target_type))
+            raise Exception("A converter does not exist for {} to {}.".format(original_dataset.ext, target_type))
         # Generate parameter dictionary
         params = {}
         # determine input parameter name and add to params
@@ -682,7 +673,7 @@ class Data(object):
                 value.visible = False
         if return_output:
             return converted_dataset
-        return "The file conversion of %s on data %s has been added to the Queue." % (converter.name, original_dataset.hid)
+        return "The file conversion of {} on data {} has been added to the Queue.".format(converter.name, original_dataset.hid)
 
     # We need to clear associated files before we set metadata
     # so that as soon as metadata starts to be set, e.g. implicitly converted datasets are deleted and no longer available 'while' metadata is being set, not just after
@@ -849,10 +840,14 @@ class Text(Data):
         Perform a rough estimate by extrapolating number of lines from a small read.
         """
         sample_size = 1048576
-        with open(dataset.file_name) as dataset_fh:
-            dataset_read = dataset_fh.read(sample_size)
-        sample_lines = dataset_read.count('\n')
-        est_lines = int(sample_lines * (float(dataset.get_size()) / float(sample_size)))
+        try:
+            with compression_utils.get_fileobj(dataset.file_name) as dataset_fh:
+                dataset_read = dataset_fh.read(sample_size)
+            sample_lines = dataset_read.count('\n')
+            est_lines = int(sample_lines * (float(dataset.get_size()) / float(sample_size)))
+        except UnicodeDecodeError:
+            log.error('Unable to estimate lines in file {}'.format(dataset.file_name))
+            est_lines = None
         return est_lines
 
     def count_data_lines(self, dataset):
@@ -874,8 +869,9 @@ class Text(Data):
                     line = line.strip()
                     if line and not line.startswith('#'):
                         data_lines += 1
-            except Exception:
-                pass
+            except UnicodeDecodeError:
+                log.error('Unable to count lines in file {}'.format(dataset.file_name))
+                data_lines = None
         return data_lines
 
     def set_peek(self, dataset, line_count=None, is_multi_byte=False, WIDTH=256, skipchars=None, line_wrap=True):
@@ -888,7 +884,7 @@ class Text(Data):
             if line_count is None:
                 # See if line_count is stored in the metadata
                 if dataset.metadata.data_lines:
-                    dataset.blurb = "%s %s" % (util.commaify(str(dataset.metadata.data_lines)), inflector.cond_plural(dataset.metadata.data_lines, self.line_class))
+                    dataset.blurb = "{} {}".format(util.commaify(str(dataset.metadata.data_lines)), inflector.cond_plural(dataset.metadata.data_lines, self.line_class))
                 else:
                     # Number of lines is not known ( this should not happen ), and auto-detect is
                     # needed to set metadata
@@ -896,13 +892,19 @@ class Text(Data):
                     if int(dataset.get_size()) <= 1048576:
                         # Small dataset, recount all lines and reset peek afterward.
                         lc = self.count_data_lines(dataset)
-                        dataset.metadata.data_lines = lc
-                        dataset.blurb = "%s %s" % (util.commaify(str(lc)), inflector.cond_plural(lc, self.line_class))
+                        if lc is not None:
+                            dataset.metadata.data_lines = lc
+                            dataset.blurb = "{} {}".format(util.commaify(str(lc)), inflector.cond_plural(lc, self.line_class))
+                        else:
+                            dataset.blurb = "Error: Cannot count lines in dataset"
                     else:
                         est_lines = self.estimate_file_lines(dataset)
-                        dataset.blurb = "~%s %s" % (util.commaify(util.roundify(str(est_lines))), inflector.cond_plural(est_lines, self.line_class))
+                        if est_lines is not None:
+                            dataset.blurb = "~{} {}".format(util.commaify(util.roundify(str(est_lines))), inflector.cond_plural(est_lines, self.line_class))
+                        else:
+                            dataset.blurb = "Error: Cannot estimate lines in dataset"
             else:
-                dataset.blurb = "%s %s" % (util.commaify(str(line_count)), inflector.cond_plural(line_count, self.line_class))
+                dataset.blurb = "{} {}".format(util.commaify(str(line_count)), inflector.cond_plural(line_count, self.line_class))
         else:
             dataset.peek = 'file does not exist'
             dataset.blurb = 'file purged from disk'
@@ -947,7 +949,7 @@ class Text(Data):
         else:
             raise Exception('Unsupported split mode %s' % split_params['split_mode'])
 
-        f = open(input_files[0], 'r')
+        f = open(input_files[0])
         try:
             chunk_idx = 0
             file_done = False
@@ -1016,7 +1018,6 @@ class LineCount(Text):
     Dataset contains a single line with a single integer that denotes the
     line count for a related dataset. Used for custom builds.
     """
-    pass
 
 
 class Newick(Text):
