@@ -53,7 +53,7 @@ class DatasetDataProvider(base.DataProvider):
         # this dataset file is obviously the source
         # TODO: this might be a good place to interface with the object_store...
         mode = 'rb' if dataset.datatype.is_binary else 'r'
-        super(DatasetDataProvider, self).__init__(open(dataset.file_name, mode))
+        super().__init__(open(dataset.file_name, mode))
 
     # TODO: this is a bit of a mess
     @classmethod
@@ -126,7 +126,7 @@ class DatasetDataProvider(base.DataProvider):
                                  getattr(self.dataset.datatype, 'column_names', None) or None)
         if not metadata_column_names:
             raise KeyError('No column_names found for ' +
-                           'datatype: %s, dataset: %s' % (str(self.dataset.datatype), str(self.dataset)))
+                           'datatype: {}, dataset: {}'.format(str(self.dataset.datatype), str(self.dataset)))
         indeces = []  # if indeces and column_names:
         # pull using indeces and re-name with given names - no need to alter (does as super would)
         #    pass
@@ -201,7 +201,7 @@ class DatasetColumnarDataProvider(column.ColumnarDataProvider):
         if not kwargs.get('column_types', None):
             indeces = kwargs.get('indeces', None)
             kwargs['column_types'] = dataset_source.get_metadata_column_types(indeces=indeces)
-        super(DatasetColumnarDataProvider, self).__init__(dataset_source, **kwargs)
+        super().__init__(dataset_source, **kwargs)
 
 
 class DatasetDictDataProvider(column.DictDataProvider):
@@ -253,7 +253,7 @@ class DatasetDictDataProvider(column.DictDataProvider):
         if not kwargs.get('column_types', None):
             kwargs['column_types'] = dataset_source.get_metadata_column_types(indeces=indeces)
 
-        super(DatasetDictDataProvider, self).__init__(dataset_source, **kwargs)
+        super().__init__(dataset_source, **kwargs)
 
 
 # ----------------------------------------------------------------------------- provides a bio-relevant datum
@@ -315,10 +315,10 @@ class GenomicRegionDataProvider(column.ColumnarDataProvider):
         if self.named_columns:
             self.column_names = self.COLUMN_NAMES
 
-        super(GenomicRegionDataProvider, self).__init__(dataset_source, **kwargs)
+        super().__init__(dataset_source, **kwargs)
 
     def __iter__(self):
-        parent_gen = super(GenomicRegionDataProvider, self).__iter__()
+        parent_gen = super().__iter__()
         for column_values in parent_gen:
             if self.named_columns:
                 yield dict(zip(self.column_names, column_values))
@@ -396,10 +396,10 @@ class IntervalDataProvider(column.ColumnarDataProvider):
 
         self.named_columns = named_columns
 
-        super(IntervalDataProvider, self).__init__(dataset_source, **kwargs)
+        super().__init__(dataset_source, **kwargs)
 
     def __iter__(self):
-        parent_gen = super(IntervalDataProvider, self).__iter__()
+        parent_gen = super().__iter__()
         for column_values in parent_gen:
             if self.named_columns:
                 yield dict(zip(self.column_names, column_values))
@@ -430,12 +430,12 @@ class FastaDataProvider(base.FilteredDataProvider):
         """
         source = bx_seq.fasta.FastaReader(source)
         # TODO: validate is a fasta
-        super(FastaDataProvider, self).__init__(source, **kwargs)
+        super().__init__(source, **kwargs)
         self.ids = ids
         # how to do ids?
 
     def __iter__(self):
-        parent_gen = super(FastaDataProvider, self).__iter__()
+        parent_gen = super().__iter__()
         for fasta_record in parent_gen:
             yield {
                 'id'  : fasta_record.name,
@@ -504,13 +504,13 @@ class WiggleDataProvider(base.LimitedOffsetDataProvider):
         # still good to maintain a ref to the raw source bc Reader won't
         self.raw_source = source
         self.parser = bx_wig.Reader(source)
-        super(WiggleDataProvider, self).__init__(self.parser, **kwargs)
+        super().__init__(self.parser, **kwargs)
 
         self.named_columns = named_columns
         self.column_names = column_names or self.COLUMN_NAMES
 
     def __iter__(self):
-        parent_gen = super(WiggleDataProvider, self).__iter__()
+        parent_gen = super().__iter__()
         for three_tuple in parent_gen:
             if self.named_columns:
                 yield dict(zip(self.column_names, three_tuple))
@@ -560,7 +560,7 @@ class BigWigDataProvider(base.LimitedOffsetDataProvider):
         # self.column_names = column_names or self.COLUMN_NAMES
 
     def __iter__(self):
-        parent_gen = super(BigWigDataProvider, self).__iter__()
+        parent_gen = super().__iter__()
         for three_tuple in parent_gen:
             if self.named_columns:
                 yield dict(zip(self.column_names, three_tuple))
@@ -630,7 +630,7 @@ class SamtoolsDataProvider(line.RegexLineDataProvider):
         subproc_args = self.build_command_list(subcommand, options_string, options_dict, regions)
 # TODO: the composition/inheritance here doesn't make a lot sense
         subproc_provider = external.SubprocessDataProvider(*subproc_args)
-        super(SamtoolsDataProvider, self).__init__(subproc_provider, **kwargs)
+        super().__init__(subproc_provider, **kwargs)
 
     def build_command_list(self, subcommand, options_string, options_dict, regions):
         """
@@ -727,12 +727,11 @@ class SQliteDataProvider(base.DataProvider):
     def __init__(self, source, query=None, **kwargs):
         self.query = query
         self.connection = sqlite.connect(source.dataset.file_name)
-        super(SQliteDataProvider, self).__init__(source, **kwargs)
+        super().__init__(source, **kwargs)
 
     def __iter__(self):
         if (self.query is not None) and sqlite.is_read_only_query(self.query):
-            for row in self.connection.cursor().execute(self.query):
-                yield row
+            yield from self.connection.cursor().execute(self.query)
         else:
             yield
 
@@ -753,7 +752,7 @@ class SQliteDataTableProvider(base.DataProvider):
         self.headers = headers
         self.limit = limit
         self.connection = sqlite.connect(source.dataset.file_name)
-        super(SQliteDataTableProvider, self).__init__(source, **kwargs)
+        super().__init__(source, **kwargs)
 
     def __iter__(self):
         if (self.query is not None) and sqlite.is_read_only_query(self.query):
@@ -781,12 +780,12 @@ class SQliteDataDictProvider(base.DataProvider):
     def __init__(self, source, query=None, **kwargs):
         self.query = query
         self.connection = sqlite.connect(source.dataset.file_name)
-        super(SQliteDataDictProvider, self).__init__(source, **kwargs)
+        super().__init__(source, **kwargs)
 
     def __iter__(self):
         if (self.query is not None) and sqlite.is_read_only_query(self.query):
             cur = self.connection.cursor()
             for row in cur.execute(self.query):
-                yield [dict((cur.description[i][0], value) for i, value in enumerate(row))]
+                yield [{cur.description[i][0]: value for i, value in enumerate(row)}]
         else:
             yield
