@@ -264,7 +264,7 @@ class Interval(Tabular):
                                      (base_url, app.url_for(controller='root'), dataset.id, type))
             redirect_url = quote_plus("%sdb=%s&position=%s:%s-%s&hgt.customText=%%s" %
                                       (site_url, dataset.dbkey, chrom, start, stop))
-            link = '%s?redirect_url=%s&display_url=%s' % (internal_url, redirect_url, display_url)
+            link = '{}?redirect_url={}&display_url={}'.format(internal_url, redirect_url, display_url)
             ret_val.append((site_name, link))
         return ret_val
 
@@ -477,9 +477,9 @@ class Bed(Interval):
         if not get_headers(file_prefix, '\t', comment_designator='#', count=1):
             return False
         try:
-            headers = iter_headers(file_prefix, '\t', comment_designator='#')
-            for hdr in headers:
-                if hdr[0] == '':
+            found_valid_lines = False
+            for hdr in iter_headers(file_prefix, '\t', comment_designator='#'):
+                if not hdr or hdr == ['']:
                     continue
                 if len(hdr) < 3 or len(hdr) > 12:
                     return False
@@ -542,7 +542,8 @@ class Bed(Interval):
                         return False
                     if len(block_sizes) != block_count or len(block_starts) != block_count:
                         return False
-            return True
+                found_valid_lines = True
+            return found_valid_lines
         except Exception:
             return False
 
@@ -597,18 +598,18 @@ class Bed12(BedStrict):
     file_ext = "bed12"
 
 
-class _RemoteCallMixin(object):
+class _RemoteCallMixin:
     def _get_remote_call_url(self, redirect_url, site_name, dataset, type, app, base_url):
         """Retrieve the URL to call out to an external site and retrieve data.
         This routes our external URL through a local galaxy instance which makes
         the data available, followed by redirecting to the remote site with a
         link back to the available information.
         """
-        internal_url = "%s" % app.url_for(controller='dataset', dataset_id=dataset.id, action='display_at', filename='%s_%s' % (type, site_name))
+        internal_url = "%s" % app.url_for(controller='dataset', dataset_id=dataset.id, action='display_at', filename='{}_{}'.format(type, site_name))
         base_url = app.config.get("display_at_callback", base_url)
         display_url = quote_plus("%s%s/display_as?id=%i&display_app=%s&authz_method=display_at" %
                                  (base_url, app.url_for(controller='root'), dataset.id, type))
-        link = '%s?redirect_url=%s&display_url=%s' % (internal_url, redirect_url, display_url)
+        link = '{}?redirect_url={}&display_url={}'.format(internal_url, redirect_url, display_url)
         return link
 
 
@@ -794,7 +795,7 @@ class Gff(Tabular, _RemoteCallMixin):
                 if site_name in app.datatypes_registry.get_display_sites('gbrowse'):
                     if seqid.startswith('chr') and len(seqid) > 3:
                         seqid = seqid[3:]
-                    redirect_url = quote_plus("%s/?q=%s:%s..%s&eurl=%%s" % (site_url, seqid, start, stop))
+                    redirect_url = quote_plus("{}/?q={}:{}..{}&eurl=%s".format(site_url, seqid, start, stop))
                     link = self._get_remote_call_url(redirect_url, site_name, dataset, type, app, base_url)
                     ret_val.append((site_name, link))
         return ret_val
@@ -818,28 +819,33 @@ class Gff(Tabular, _RemoteCallMixin):
         if len(get_headers(file_prefix, '\t', count=2)) < 2:
             return False
         try:
-            headers = iter_headers(file_prefix, '\t')
-            for hdr in headers:
-                if hdr and hdr[0].startswith('##gff-version') and hdr[0].find('2') < 0:
+            found_valid_lines = False
+            for hdr in iter_headers(file_prefix, '\t'):
+                if not hdr or hdr == ['']:
+                    continue
+                if hdr[0].startswith('##gff-version') and hdr[0].find('2') < 0:
                     return False
-                if hdr and hdr[0] and not hdr[0].startswith('#'):
-                    if len(hdr) != 9:
-                        return False
+                # The gff-version header comment may have been stripped, so inspect the data
+                if hdr[0].startswith('#'):
+                    continue
+                if len(hdr) != 9:
+                    return False
+                try:
+                    int(hdr[3])
+                    int(hdr[4])
+                except Exception:
+                    return False
+                if hdr[5] != '.':
                     try:
-                        int(hdr[3])
-                        int(hdr[4])
+                        float(hdr[5])
                     except Exception:
                         return False
-                    if hdr[5] != '.':
-                        try:
-                            float(hdr[5])
-                        except Exception:
-                            return False
-                    if hdr[6] not in data.valid_strand:
-                        return False
-                    if hdr[7] not in self.valid_gff_frame:
-                        return False
-            return True
+                if hdr[6] not in data.valid_strand:
+                    return False
+                if hdr[7] not in self.valid_gff_frame:
+                    return False
+                found_valid_lines = True
+            return found_valid_lines
         except Exception:
             return False
 
@@ -946,41 +952,48 @@ class Gff3(Gff):
         >>> fname = get_test_fname('gff.gff3')
         >>> Gff3().sniff( fname )
         True
+        >>> fname = get_test_fname( 'grch37.75.gtf' )
+        >>> Gff3().sniff( fname )
+        False
         """
         if len(get_headers(file_prefix, '\t', count=2)) < 2:
             return False
         try:
-            headers = iter_headers(file_prefix, '\t')
-            for hdr in headers:
-                if hdr and hdr[0].startswith('##gff-version') and hdr[0].find('3') >= 0:
+            found_valid_lines = False
+            for hdr in iter_headers(file_prefix, '\t'):
+                if not hdr or hdr == ['']:
+                    continue
+                if hdr[0].startswith('##gff-version') and hdr[0].find('3') >= 0:
                     return True
-                elif hdr and hdr[0].startswith('##gff-version') and hdr[0].find('3') < 0:
+                elif hdr[0].startswith('##gff-version') and hdr[0].find('3') < 0:
                     return False
-                # Header comments may have been stripped, so inspect the data
-                if hdr and hdr[0] and not hdr[0].startswith('#'):
-                    if len(hdr) != 9:
+                # The gff-version header comment may have been stripped, so inspect the data
+                if hdr[0].startswith('#'):
+                    continue
+                if len(hdr) != 9:
+                    return False
+                try:
+                    int(hdr[3])
+                except Exception:
+                    if hdr[3] != '.':
                         return False
+                try:
+                    int(hdr[4])
+                except Exception:
+                    if hdr[4] != '.':
+                        return False
+                if hdr[5] != '.':
                     try:
-                        int(hdr[3])
+                        float(hdr[5])
                     except Exception:
-                        if hdr[3] != '.':
-                            return False
-                    try:
-                        int(hdr[4])
-                    except Exception:
-                        if hdr[4] != '.':
-                            return False
-                    if hdr[5] != '.':
-                        try:
-                            float(hdr[5])
-                        except Exception:
-                            return False
-                    if hdr[6] not in self.valid_gff3_strand:
                         return False
-                    if hdr[7] not in self.valid_gff3_phase:
-                        return False
-                    parse_gff3_attributes(hdr[8])
-            return True
+                if hdr[6] not in self.valid_gff3_strand:
+                    return False
+                if hdr[7] not in self.valid_gff3_phase:
+                    return False
+                parse_gff3_attributes(hdr[8])
+                found_valid_lines = True
+            return found_valid_lines
         except Exception:
             return False
 
@@ -1021,42 +1034,45 @@ class Gtf(Gff):
         >>> fname = get_test_fname( 'test.gtf' )
         >>> Gtf().sniff( fname )
         True
+        >>> fname = get_test_fname( 'grch37.75.gtf' )
+        >>> Gtf().sniff( fname )
+        True
         """
         if len(get_headers(file_prefix, '\t', count=2)) < 2:
             return False
         try:
-            headers = iter_headers(file_prefix, '\t')
-            for hdr in headers:
-                if hdr and hdr[0].startswith('##gff-version') and hdr[0].find('2') < 0:
+            found_valid_lines = False
+            for hdr in iter_headers(file_prefix, '\t'):
+                if not hdr or hdr == ['']:
+                    continue
+                if hdr[0].startswith('##gff-version') and hdr[0].find('2') < 0:
                     return False
-                if hdr and hdr[0] and not hdr[0].startswith('#'):
-                    if len(hdr) != 9:
-                        return False
+                # The gff-version header comment may have been stripped, so inspect the data
+                if hdr[0].startswith('#'):
+                    continue
+                if len(hdr) != 9:
+                    return False
+                try:
+                    int(hdr[3])
+                    int(hdr[4])
+                except Exception:
+                    return False
+                if hdr[5] != '.':
                     try:
-                        int(hdr[3])
-                        int(hdr[4])
+                        float(hdr[5])
                     except Exception:
                         return False
-                    if hdr[5] != '.':
-                        try:
-                            float(hdr[5])
-                        except Exception:
-                            return False
-                    if hdr[6] not in data.valid_strand:
-                        return False
-                    if hdr[7] not in self.valid_gff_frame:
-                        return False
-
-                    # Check attributes for gene_id, transcript_id
-                    attributes = parse_gff_attributes(hdr[8])
-                    if len(attributes) >= 2:
-                        if 'gene_id' not in attributes:
-                            return False
-                        if 'transcript_id' not in attributes:
-                            return False
-                    else:
-                        return False
-            return True
+                if hdr[6] not in data.valid_strand:
+                    return False
+                if hdr[7] not in self.valid_gff_frame:
+                    return False
+                # Check attributes for gene_id (transcript_id is also mandatory
+                # but not for genes)
+                attributes = parse_gff_attributes(hdr[8])
+                if 'gene_id' not in attributes:
+                    return False
+                found_valid_lines = True
+            return found_valid_lines
         except Exception:
             return False
 
@@ -1089,7 +1105,7 @@ class Wiggle(Tabular, _RemoteCallMixin):
                 span = 1
                 step = None
                 with open(dataset.file_name) as fh:
-                    for line in util.iter_readline_count(fh, VIEWPORT_READLINE_BUFFER_SIZE):
+                    for line in util.iter_start_of_line(fh, VIEWPORT_READLINE_BUFFER_SIZE):
                         try:
                             if line.startswith("browser"):
                                 chr_info = line.rstrip('\n\r').split()[-1]
@@ -1146,7 +1162,7 @@ class Wiggle(Tabular, _RemoteCallMixin):
                 if site_name in app.datatypes_registry.get_display_sites('gbrowse'):
                     if chrom.startswith('chr') and len(chrom) > 3:
                         chrom = chrom[3:]
-                    redirect_url = quote_plus("%s/?q=%s:%s..%s&eurl=%%s" % (site_url, chrom, start, stop))
+                    redirect_url = quote_plus("{}/?q={}:{}..{}&eurl=%s".format(site_url, chrom, start, stop))
                     link = self._get_remote_call_url(redirect_url, site_name, dataset, type, app, base_url)
                     ret_val.append((site_name, link))
         return ret_val
@@ -1157,7 +1173,7 @@ class Wiggle(Tabular, _RemoteCallMixin):
         if chrom is not None:
             for site_name, site_url in app.datatypes_registry.get_legacy_sites_by_build('ucsc', dataset.dbkey):
                 if site_name in app.datatypes_registry.get_display_sites('ucsc'):
-                    redirect_url = quote_plus("%sdb=%s&position=%s:%s-%s&hgt.customText=%%s" % (site_url, dataset.dbkey, chrom, start, stop))
+                    redirect_url = quote_plus("{}db={}&position={}:{}-{}&hgt.customText=%s".format(site_url, dataset.dbkey, chrom, start, stop))
                     link = self._get_remote_call_url(redirect_url, site_name, dataset, type, app, base_url)
                     ret_val.append((site_name, link))
         return ret_val
@@ -1324,8 +1340,8 @@ class CustomTrack(Tabular):
                 if site_name in app.datatypes_registry.get_display_sites('ucsc'):
                     internal_url = "%s" % app.url_for(controller='dataset', dataset_id=dataset.id, action='display_at', filename='ucsc_' + site_name)
                     display_url = quote_plus("%s%s/display_as?id=%i&display_app=%s&authz_method=display_at" % (base_url, app.url_for(controller='root'), dataset.id, type))
-                    redirect_url = quote_plus("%sdb=%s&position=%s:%s-%s&hgt.customText=%%s" % (site_url, dataset.dbkey, chrom, start, stop))
-                    link = '%s?redirect_url=%s&display_url=%s' % (internal_url, redirect_url, display_url)
+                    redirect_url = quote_plus("{}db={}&position={}:{}-{}&hgt.customText=%s".format(site_url, dataset.dbkey, chrom, start, stop))
+                    link = '{}?redirect_url={}&display_url={}'.format(internal_url, redirect_url, display_url)
                     ret_val.append((site_name, link))
         return ret_val
 
