@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import logging
 import os
 import re
@@ -500,7 +499,7 @@ class PDB(GenericMolFile):
         """
         try:
             chain_ids = set()
-            with open(dataset.file_name, 'r') as fh:
+            with open(dataset.file_name) as fh:
                 for line in fh:
                     if line.startswith('ATOM  ') or line.startswith('HETATM'):
                         if line[21] != ' ':
@@ -516,7 +515,7 @@ class PDB(GenericMolFile):
             hetatm_numbers = count_special_lines("^HETATM", dataset.file_name)
             chain_ids = ','.join(dataset.metadata.chain_ids) if len(dataset.metadata.chain_ids) > 0 else 'None'
             dataset.peek = get_file_peek(dataset.file_name)
-            dataset.blurb = "%s atoms and %s HET-atoms\nchain_ids: %s" % (atom_numbers, hetatm_numbers, chain_ids)
+            dataset.blurb = "{} atoms and {} HET-atoms\nchain_ids: {}".format(atom_numbers, hetatm_numbers, chain_ids)
         else:
             dataset.peek = 'file does not exist'
             dataset.blurb = 'file purged from disk'
@@ -567,7 +566,7 @@ class PDBQT(GenericMolFile):
             root_numbers = count_special_lines("^ROOT", dataset.file_name)
             branch_numbers = count_special_lines("^BRANCH", dataset.file_name)
             dataset.peek = get_file_peek(dataset.file_name)
-            dataset.blurb = "%s roots and %s branches" % (root_numbers, branch_numbers)
+            dataset.blurb = "{} roots and {} branches".format(root_numbers, branch_numbers)
         else:
             dataset.peek = 'file does not exist'
             dataset.blurb = 'file purged from disk'
@@ -651,7 +650,7 @@ class PQR(GenericMolFile):
         try:
             prog = self.get_matcher()
             chain_ids = set()
-            with open(dataset.file_name, 'r') as fh:
+            with open(dataset.file_name) as fh:
                 for line in fh:
                     if line.startswith('REMARK'):
                         continue
@@ -669,7 +668,7 @@ class PQR(GenericMolFile):
             hetatm_numbers = count_special_lines("^HETATM", dataset.file_name)
             chain_ids = ','.join(dataset.metadata.chain_ids) if len(dataset.metadata.chain_ids) > 0 else 'None'
             dataset.peek = get_file_peek(dataset.file_name)
-            dataset.blurb = "%s atoms and %s HET-atoms\nchain_ids: %s" % (atom_numbers, hetatm_numbers, str(chain_ids))
+            dataset.blurb = "{} atoms and {} HET-atoms\nchain_ids: {}".format(atom_numbers, hetatm_numbers, str(chain_ids))
         else:
             dataset.peek = 'file does not exist'
             dataset.blurb = 'file purged from disk'
