@@ -1,7 +1,6 @@
 """
 Provides mapping between extensions and datatypes, mime-types, etc.
 """
-from __future__ import absolute_import
 
 import imp
 import logging
@@ -34,7 +33,7 @@ class ConfigurationError(Exception):
     pass
 
 
-class Registry(object):
+class Registry:
 
     def __init__(self, config=None):
         self.log = logging.getLogger(__name__)
@@ -248,14 +247,14 @@ class Registry(object):
                                         for mod in fields:
                                             module = getattr(module, mod)
                                         datatype_class = getattr(module, datatype_class_name)
-                                        self.log.debug('Retrieved datatype module %s:%s from the datatype registry for extension %s.' % (str(datatype_module), datatype_class_name, extension))
+                                        self.log.debug('Retrieved datatype module {}:{} from the datatype registry for extension {}.'.format(str(datatype_module), datatype_class_name, extension))
                                     except Exception:
                                         self.log.exception('Error importing datatype module %s', str(datatype_module))
                                         ok = False
                         elif type_extension is not None:
                             try:
                                 datatype_class = self.datatypes_by_extension[type_extension].__class__
-                                self.log.debug('Retrieved datatype module %s from type_extension %s for extension %s.' % (str(datatype_class.__name__), type_extension, extension))
+                                self.log.debug('Retrieved datatype module {} from type_extension {} for extension {}.'.format(str(datatype_class.__name__), type_extension, extension))
                             except Exception:
                                 self.log.exception('Error determining datatype_class for type_extension %s', str(type_extension))
                                 ok = False
@@ -331,7 +330,7 @@ class Registry(object):
                                 self.datatype_info_dicts.append(datatype_info_dict)
 
                                 for auto_compressed_type in auto_compressed_types:
-                                    compressed_extension = "%s.%s" % (extension, auto_compressed_type)
+                                    compressed_extension = "{}.{}".format(extension, auto_compressed_type)
                                     upper_compressed_type = auto_compressed_type[0].upper() + auto_compressed_type[1:]
                                     auto_compressed_type_name = datatype_class_name + upper_compressed_type
                                     attributes = {}
@@ -373,7 +372,7 @@ class Registry(object):
                                     if not override:
                                         # Do not load the datatype since it conflicts with an existing datatype which we are not supposed
                                         # to override.
-                                        self.log.debug("Ignoring conflicting datatype with extension '%s' from %s." % (extension, config))
+                                        self.log.debug("Ignoring conflicting datatype with extension '{}' from {}.".format(extension, config))
             # Load datatype sniffers from the config - we'll do this even if one or more datatypes were not properly processed in the config
             # since sniffers are not tightly coupled with datatypes.
             self.load_datatype_sniffers(root,
@@ -388,7 +387,7 @@ class Registry(object):
         self.set_default_values()
 
         def append_to_sniff_order():
-            sniff_order_classes = set(type(_) for _ in self.sniff_order)
+            sniff_order_classes = {type(_) for _ in self.sniff_order}
             for datatype in self.datatypes_by_extension.values():
                 # Add a datatype only if it is not already in sniff_order, it
                 # has a sniff() method and was not defined with subclass="true".
@@ -414,7 +413,7 @@ class Registry(object):
             if not os.path.exists(path):
                 sample_path = "%s.sample" % path
                 if os.path.exists(sample_path):
-                    self.log.debug("Build site file [%s] not found using sample [%s]." % (path, sample_path))
+                    self.log.debug("Build site file [{}] not found using sample [{}].".format(path, sample_path))
                     path = sample_path
 
             self.build_sites[site_type] = path
@@ -435,7 +434,7 @@ class Registry(object):
         else:
             build_sites_config_file = getattr(self.config, "build_sites_config_file", None)
             if build_sites_config_file and os.path.exists(build_sites_config_file):
-                with open(build_sites_config_file, "r") as f:
+                with open(build_sites_config_file) as f:
                     build_sites_config = yaml.safe_load(f)
                 if not isinstance(build_sites_config, list):
                     self.log.exception("Build sites configuration YAML file does not declare list of sites.")
@@ -704,13 +703,13 @@ class Registry(object):
                                     del self.datatypes_by_extension[extension].display_applications[display_app.id]
                             if inherit and (self.datatypes_by_extension[extension], display_app) in self.inherit_display_application_by_class:
                                 self.inherit_display_application_by_class.remove((self.datatypes_by_extension[extension], display_app))
-                            self.log.debug("Deactivated display application '%s' for datatype '%s'." % (display_app.id, extension))
+                            self.log.debug("Deactivated display application '{}' for datatype '{}'.".format(display_app.id, extension))
                         else:
                             self.display_applications[display_app.id] = display_app
                             self.datatypes_by_extension[extension].add_display_application(display_app)
                             if inherit and (self.datatypes_by_extension[extension], display_app) not in self.inherit_display_application_by_class:
                                 self.inherit_display_application_by_class.append((self.datatypes_by_extension[extension], display_app))
-                            self.log.debug("Loaded display application '%s' for datatype '%s', inherit=%s." % (display_app.id, extension, inherit))
+                            self.log.debug("Loaded display application '{}' for datatype '{}', inherit={}.".format(display_app.id, extension, inherit))
                 except Exception:
                     if deactivate:
                         self.log.exception("Error deactivating display application (%s)" % config_path)
@@ -721,7 +720,7 @@ class Registry(object):
             for d_type2, display_app in self.inherit_display_application_by_class:
                 current_app = d_type1.get_display_application(display_app.id, None)
                 if current_app is None and isinstance(d_type1, type(d_type2)):
-                    self.log.debug("Adding inherited display application '%s' to datatype '%s'" % (display_app.id, extension))
+                    self.log.debug("Adding inherited display application '{}' to datatype '{}'".format(display_app.id, extension))
                     d_type1.add_display_application(display_app)
 
     def reload_display_applications(self, display_application_ids=None):
@@ -884,7 +883,11 @@ class Registry(object):
         return None
 
     def find_conversion_destination_for_dataset_by_extensions(self, dataset_or_ext, accepted_formats, converter_safe=True):
-        """Returns ( target_ext, existing converted dataset )"""
+        """
+        returns (direct_match, converted_ext, converted_dataset)
+        - direct match is True iff no the data set already has an accepted format
+        - target_ext becomes None if conversion is not possible (or necesary)
+        """
         if hasattr(dataset_or_ext, "ext"):
             ext = dataset_or_ext.ext
             dataset = dataset_or_ext
@@ -892,10 +895,13 @@ class Registry(object):
             ext = dataset_or_ext
             dataset = None
 
+        if self.get_datatype_by_extension(ext) is not None and self.get_datatype_by_extension(ext).matches_any(accepted_formats):
+            return True, None, None
+
         for convert_ext in self.get_converters_by_datatype(ext):
             convert_ext_datatype = self.get_datatype_by_extension(convert_ext)
             if convert_ext_datatype is None:
-                self.log.warning("Datatype class not found for extension '%s', which is used as target for conversion from datatype '%s'" % (convert_ext, dataset.ext))
+                self.log.warning("Datatype class not found for extension '{}', which is used as target for conversion from datatype '{}'".format(convert_ext, dataset.ext))
             elif convert_ext_datatype.matches_any(accepted_formats):
                 converted_dataset = dataset and dataset.get_converted_files_by_type(convert_ext)
                 if converted_dataset:
@@ -904,8 +910,8 @@ class Registry(object):
                     continue
                 else:
                     ret_data = None
-                return (convert_ext, ret_data)
-        return (None, None)
+                return False, convert_ext, ret_data
+        return False, None, None
 
     def get_composite_extensions(self):
         return [ext for (ext, d_type) in self.datatypes_by_extension.items() if d_type.composite_type is not None]
@@ -920,7 +926,7 @@ class Registry(object):
                     help_txt = meta_spec.desc
                     if not help_txt or help_txt == meta_name:
                         help_txt = ""
-                    inputs.append('<param type="text" name="%s" label="Set metadata value for &quot;%s&quot;" value="%s" help="%s"/>' % (meta_name, meta_name, meta_spec.default, help_txt))
+                    inputs.append('<param type="text" name="{}" label="Set metadata value for &quot;{}&quot;" value="{}" help="{}"/>'.format(meta_name, meta_name, meta_spec.default, help_txt))
             rval[ext] = "\n".join(inputs)
         if 'auto' not in rval and 'txt' in rval:  # need to manually add 'auto' datatype
             rval['auto'] = rval['txt']
@@ -931,7 +937,7 @@ class Registry(object):
         """
         """
         if not self._edam_formats_mapping:
-            self._edam_formats_mapping = dict((k, v.edam_format) for k, v in self.datatypes_by_extension.items())
+            self._edam_formats_mapping = {k: v.edam_format for k, v in self.datatypes_by_extension.items()}
         return self._edam_formats_mapping
 
     @property
@@ -939,7 +945,7 @@ class Registry(object):
         """
         """
         if not self._edam_data_mapping:
-            self._edam_data_mapping = dict((k, v.edam_data) for k, v in self.datatypes_by_extension.items())
+            self._edam_data_mapping = {k: v.edam_data for k, v in self.datatypes_by_extension.items()}
         return self._edam_data_mapping
 
     def to_xml_file(self, path):
@@ -956,8 +962,8 @@ class Registry(object):
             """)
             converters_path = self.converters_path_attr or ''
             display_path = self.display_path_attr or ''
-            datatype_elems = "".join((galaxy.util.xml_to_string(elem) for elem in self.datatype_elems))
-            sniffer_elems = "".join((galaxy.util.xml_to_string(elem) for elem in self.sniffer_elems))
+            datatype_elems = "".join(galaxy.util.xml_to_string(elem) for elem in self.datatype_elems)
+            sniffer_elems = "".join(galaxy.util.xml_to_string(elem) for elem in self.sniffer_elems)
             self._registry_xml_string = registry_string_template.substitute(converters_path=converters_path,
                                                                             display_path=display_path,
                                                                             datatype_elems=datatype_elems,
