@@ -8,7 +8,6 @@ import os
 import re
 import string
 import subprocess
-import sys
 from itertools import islice
 
 import bx.align.maf
@@ -36,9 +35,6 @@ from galaxy.util.checkers import (
 from galaxy.util.image_util import check_image_type
 from . import data
 
-if sys.version_info > (3,):
-    long = int
-
 log = logging.getLogger(__name__)
 
 
@@ -133,7 +129,7 @@ class Sequence(data.Text):
                 sequences_per_file[i] += 1
         elif split_params['split_mode'] == 'to_size':
             # loop through the sections and calculate the number of sequences
-            chunk_size = long(split_params['split_size'])
+            chunk_size = int(split_params['split_size'])
             rem = total_sequences % chunk_size
             sequences_per_file = [chunk_size for i in range(total_sequences / chunk_size)]
             # TODO: Should we invest the time in a better way to handle small remainders?
@@ -151,7 +147,7 @@ class Sequence(data.Text):
             total_sequences = input_datasets[0].metadata.sequences
         else:
             with compression_utils.get_fileobj(input_datasets[0].file_name) as in_file:
-                total_sequences = long(0)
+                total_sequences = int(0)
                 for i, line in enumerate(in_file):
                     total_sequences += 1
             total_sequences /= 4
@@ -163,9 +159,9 @@ class Sequence(data.Text):
     def do_fast_split(cls, input_datasets, toc_file_datasets, subdir_generator_function, split_params):
         data = json.load(open(toc_file_datasets[0].file_name))
         sections = data['sections']
-        total_sequences = long(0)
+        total_sequences = int(0)
         for section in sections:
-            total_sequences += long(section['sequences'])
+            total_sequences += int(section['sequences'])
         sequences_per_file = cls.get_sequences_per_file(total_sequences, split_params)
         return cls.write_split_files(input_datasets, toc_file_datasets, subdir_generator_function, sequences_per_file)
     do_fast_split = classmethod(do_fast_split)
@@ -190,7 +186,7 @@ class Sequence(data.Text):
                 ds = input_datasets[ds_no]
                 base_name = os.path.basename(ds.file_name)
                 part_path = os.path.join(dir, base_name)
-                split_data = dict(class_name='%s.%s' % (cls.__module__, cls.__name__),
+                split_data = dict(class_name='{}.{}'.format(cls.__module__, cls.__name__),
                                   output_name=part_path,
                                   input_name=ds.file_name,
                                   args=dict(start_sequence=start_sequence, num_sequences=sequences_per_file[part_no]))
@@ -230,30 +226,30 @@ class Sequence(data.Text):
         sections = toc_file['sections']
         result = []
 
-        current_sequence = long(0)
+        current_sequence = int(0)
         i = 0
         # skip to the section that contains my starting sequence
-        while i < len(sections) and start_sequence >= current_sequence + long(sections[i]['sequences']):
-            current_sequence += long(sections[i]['sequences'])
+        while i < len(sections) and start_sequence >= current_sequence + int(sections[i]['sequences']):
+            current_sequence += int(sections[i]['sequences'])
             i += 1
         if i == len(sections):  # bad input data!
             raise Exception('No FQTOC section contains starting sequence %s' % start_sequence)
 
         # These two variables act as an accumulator for consecutive entire blocks that
         # can be copied verbatim (without decompressing)
-        start_chunk = long(-1)
-        end_chunk = long(-1)
+        start_chunk = int(-1)
+        end_chunk = int(-1)
         copy_chunk_cmd = 'dd bs=1 skip=%s count=%s if=%s 2> /dev/null >> %s'
 
         while sequence_count > 0 and i < len(sections):
             # we need to extract partial data. So, find the byte offsets of the chunks that contain the data we need
             # use a combination of dd (to pull just the right sections out) tail (to skip lines) and head (to get the
             # right number of lines
-            sequences = long(sections[i]['sequences'])
+            sequences = int(sections[i]['sequences'])
             skip_sequences = start_sequence - current_sequence
             sequences_to_extract = min(sequence_count, sequences - skip_sequences)
-            start_copy = long(sections[i]['start'])
-            end_copy = long(sections[i]['end'])
+            start_copy = int(sections[i]['start'])
+            end_copy = int(sections[i]['end'])
             if sequences_to_extract < sequences:
                 if start_chunk > -1:
                     result.append(copy_chunk_cmd % (start_chunk, end_chunk - start_chunk, input_name, output_name))
@@ -290,9 +286,9 @@ class Sequence(data.Text):
         line_count = sequence_count * 4
         # TODO: verify that tail can handle 64-bit numbers
         if is_compressed:
-            cmd = 'zcat "%s" | ( tail -n +%s 2> /dev/null) | head -%s | gzip -c' % (input_name, start_line + 1, line_count)
+            cmd = 'zcat "{}" | ( tail -n +{} 2> /dev/null) | head -{} | gzip -c'.format(input_name, start_line + 1, line_count)
         else:
-            cmd = 'tail -n +%s "%s" 2> /dev/null | head -%s' % (start_line + 1, input_name, line_count)
+            cmd = 'tail -n +{} "{}" 2> /dev/null | head -{}'.format(start_line + 1, input_name, line_count)
         cmd += ' > "%s"' % output_name
 
         return [cmd]
@@ -427,7 +423,7 @@ class Fasta(Sequence):
         start of a new FASTQ sequence record.
         """
         log.debug("Attemping to split FASTA file %s into chunks of %i bytes" % (input_file, chunk_size))
-        f = open(input_file, "rU")
+        f = open(input_file)
         part_file = None
         try:
             # Note if the input FASTA file has no sequences, we will
@@ -435,7 +431,7 @@ class Fasta(Sequence):
             part_dir = subdir_generator_function()
             part_path = os.path.join(part_dir, os.path.basename(input_file))
             part_file = open(part_path, 'w')
-            log.debug("Writing %s part to %s" % (input_file, part_path))
+            log.debug("Writing {} part to {}".format(input_file, part_path))
             start_offset = 0
             while True:
                 offset = f.tell()
@@ -448,7 +444,7 @@ class Fasta(Sequence):
                     part_dir = subdir_generator_function()
                     part_path = os.path.join(part_dir, os.path.basename(input_file))
                     part_file = open(part_path, 'w')
-                    log.debug("Writing %s part to %s" % (input_file, part_path))
+                    log.debug("Writing {} part to {}".format(input_file, part_path))
                     start_offset = f.tell()
                 part_file.write(line)
         except Exception as e:
@@ -463,7 +459,7 @@ class Fasta(Sequence):
     def _count_split(cls, input_file, chunk_size, subdir_generator_function):
         """Split a FASTA file into chunks based on counting records."""
         log.debug("Attemping to split FASTA file %s into chunks of %i sequences" % (input_file, chunk_size))
-        f = open(input_file, "rU")
+        f = open(input_file)
         part_file = None
         try:
             # Note if the input FASTA file has no sequences, we will
@@ -471,7 +467,7 @@ class Fasta(Sequence):
             part_dir = subdir_generator_function()
             part_path = os.path.join(part_dir, os.path.basename(input_file))
             part_file = open(part_path, 'w')
-            log.debug("Writing %s part to %s" % (input_file, part_path))
+            log.debug("Writing {} part to {}".format(input_file, part_path))
             rec_count = 0
             while True:
                 line = f.readline()
@@ -485,7 +481,7 @@ class Fasta(Sequence):
                         part_dir = subdir_generator_function()
                         part_path = os.path.join(part_dir, os.path.basename(input_file))
                         part_file = open(part_path, 'w')
-                        log.debug("Writing %s part to %s" % (input_file, part_path))
+                        log.debug("Writing {} part to {}".format(input_file, part_path))
                         rec_count = 1
                 part_file.write(line)
         except Exception as e:
@@ -637,7 +633,7 @@ class Fastg(Sequence):
             dataset.blurb += '\nversion=%s' % dataset.metadata.version
             for k, v in dataset.metadata.properties.items():
                 if k != 'version':
-                    dataset.blurb += '\n%s=%s' % (k, v)
+                    dataset.blurb += '\n{}={}'.format(k, v)
         else:
             dataset.peek = 'file does not exist'
             dataset.blurb = 'file purged from disk'
@@ -776,11 +772,12 @@ class BaseFastq(Sequence):
         args = data['args']
         input_name = data['input_name']
         output_name = data['output_name']
-        start_sequence = long(args['start_sequence'])
-        sequence_count = long(args['num_sequences'])
+        start_sequence = int(args['start_sequence'])
+        sequence_count = int(args['num_sequences'])
 
         if 'toc_file' in args:
-            toc_file = json.load(open(args['toc_file'], 'r'))
+            with open(args['toc_file']) as f:
+                toc_file = json.load(f)
             commands = Sequence.get_split_commands_with_toc(input_name, output_name, toc_file, start_sequence, sequence_count)
         else:
             commands = Sequence.get_split_commands_sequential(is_gzip(input_name), input_name, output_name, start_sequence, sequence_count)
@@ -899,7 +896,7 @@ class Maf(Alignment):
             chrom_file = dataset.metadata.spec['species_chromosomes'].param.new_file(dataset=dataset)
         with open(chrom_file.file_name, 'w') as chrom_out:
             for spec, chroms in species_chromosomes.items():
-                chrom_out.write("%s\t%s\n" % (spec, "\t".join(chroms)))
+                chrom_out.write("{}\t{}\n".format(spec, "\t".join(chroms)))
         dataset.metadata.species_chromosomes = chrom_file
 
         index_file = dataset.metadata.maf_index
