@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """ Clearing house for generic text datatypes that are not XML or tabular.
 """
 
@@ -55,7 +54,7 @@ class Html(Text):
         True
         """
         headers = iter_headers(file_prefix, None)
-        for i, hdr in enumerate(headers):
+        for hdr in headers:
             if hdr and hdr[0].lower().find('<html>') >= 0:
                 return True
         return False
@@ -167,7 +166,7 @@ class Ipynb(Json):
         if trust:
             return self._display_data_trusted(trans, dataset, preview=preview, filename=filename, to_ext=to_ext, **kwd)
         else:
-            return super(Ipynb, self).display_data(trans, dataset, preview=preview, filename=filename, to_ext=to_ext, **kwd)
+            return super().display_data(trans, dataset, preview=preview, filename=filename, to_ext=to_ext, **kwd)
 
     def _display_data_trusted(self, trans, dataset, preview=False, filename=None, to_ext=None, **kwd):
         preview = string_as_bool(preview)
@@ -189,7 +188,6 @@ class Ipynb(Json):
         """
         Set the number of models in dataset.
         """
-        pass
 
 
 @build_sniff_from_prefix
@@ -215,7 +213,7 @@ class Biom1(Json):
     MetadataElement(name="table_column_metadata_headers", default=[], desc="table_column_metadata_headers", param=MetadataParameter, readonly=True, visible=True, optional=True, no_value=[])
 
     def set_peek(self, dataset, is_multi_byte=False):
-        super(Biom1, self).set_peek(dataset)
+        super().set_peek(dataset)
         if not dataset.dataset.purged:
             dataset.blurb = "Biological Observation Matrix v1"
 
@@ -234,7 +232,7 @@ class Biom1(Json):
         is_biom = False
         segment_size = int(load_size / 2)
         try:
-            with open(file_prefix.filename, "r") as fh:
+            with open(file_prefix.filename) as fh:
                 prev_str = ""
                 segment_str = fh.read(segment_size)
                 if segment_str.strip().startswith('{'):
@@ -295,7 +293,6 @@ class Biom1(Json):
                         setattr(dataset.metadata, m_name, metadata_value)
                     except Exception:
                         log.exception("Something in the metadata detection for biom1 went wrong.")
-                        pass
 
 
 @build_sniff_from_prefix
@@ -311,7 +308,7 @@ class ImgtJson(Json):
     """
 
     def set_peek(self, dataset, is_multi_byte=False):
-        super(ImgtJson, self).set_peek(dataset)
+        super().set_peek(dataset)
         if not dataset.dataset.purged:
             dataset.blurb = "IMGT Library"
 
@@ -340,7 +337,7 @@ class ImgtJson(Json):
         """
         is_imgt = False
         try:
-            with open(file_prefix.filename, "r") as fh:
+            with open(file_prefix.filename) as fh:
                 segment_str = fh.read(load_size)
                 if segment_str.strip().startswith('['):
                     if '"taxonId"' in segment_str and '"anchorPoints"' in segment_str:
@@ -358,7 +355,7 @@ class ImgtJson(Json):
                 try:
                     json_dict = json.load(fh)
                     tax_names = []
-                    for i, entry in enumerate(json_dict):
+                    for entry in json_dict:
                         if 'taxonId' in entry:
                             names = "%d: %s" % (entry['taxonId'], ','.join(entry['speciesNames']))
                             tax_names.append(names)
@@ -376,7 +373,7 @@ class GeoJson(Json):
     file_ext = "geojson"
 
     def set_peek(self, dataset, is_multi_byte=False):
-        super(GeoJson, self).set_peek(dataset)
+        super().set_peek(dataset)
         if not dataset.dataset.purged:
             dataset.blurb = "GeoJSON"
 
@@ -404,7 +401,7 @@ class GeoJson(Json):
         """
         is_geojson = False
         try:
-            with open(file_prefix.filename, "r") as fh:
+            with open(file_prefix.filename) as fh:
                 segment_str = fh.read(load_size)
                 if any(x in segment_str for x in ["Point", "MultiPoint", "LineString", "MultiLineString", "Polygon", "MultiPolygon", "GeometryCollection"]):
                     if all(x in segment_str for x in ["type", "geometry", "coordinates"]):
@@ -468,7 +465,7 @@ class Arff(Text):
         if not dataset.dataset.purged:
             dataset.peek = get_file_peek(dataset.file_name)
             dataset.blurb = "Attribute-Relation File Format (ARFF)"
-            dataset.blurb += ", %s comments, %s attributes" % (dataset.metadata.comment_lines, dataset.metadata.columns)
+            dataset.blurb += ", {} comments, {} attributes".format(dataset.metadata.comment_lines, dataset.metadata.columns)
         else:
             dataset.peek = 'file does not exist'
             dataset.blurb = 'file purged from disc'
@@ -592,7 +589,7 @@ class SnpEffDb(Text):
         genome_version = None
         snpeff_version = None
         if data_dir and os.path.isdir(data_dir):
-            for root, dirs, files in os.walk(data_dir):
+            for root, _, files in os.walk(data_dir):
                 for fname in files:
                     if fname.startswith('snpEffectPredictor'):
                         # if snpEffectPredictor.bin download succeeded
@@ -678,7 +675,7 @@ class SnpSiftDbNSFP(Text):
             efp = dataset.extra_files_path
             if os.path.exists(efp):
                 flist = os.listdir(efp)
-                for i, fname in enumerate(flist):
+                for fname in flist:
                     if fname.endswith('.gz'):
                         dataset.metadata.bgzip = fname
                         try:
@@ -697,7 +694,7 @@ class SnpSiftDbNSFP(Text):
 
         def set_peek(self, dataset, is_multi_byte=False):
             if not dataset.dataset.purged:
-                dataset.peek = '%s :  %s' % (dataset.metadata.reference_name, ','.join(dataset.metadata.annotation))
+                dataset.peek = '{} :  {}'.format(dataset.metadata.reference_name, ','.join(dataset.metadata.annotation))
                 dataset.blurb = '%s' % dataset.metadata.reference_name
             else:
                 dataset.peek = 'file does not exist'
