@@ -7,10 +7,10 @@ from .types import (
 PLUGIN_CLASSES = [list.ListDatasetCollectionType, paired.PairedDatasetCollectionType]
 
 
-class DatasetCollectionTypesRegistry(object):
+class DatasetCollectionTypesRegistry:
 
     def __init__(self):
-        self.__plugins = dict([(p.collection_type, p()) for p in PLUGIN_CLASSES])
+        self.__plugins = {p.collection_type: p() for p in PLUGIN_CLASSES}
 
     def get(self, plugin_type):
         return self.__plugins[plugin_type]
@@ -21,8 +21,8 @@ class DatasetCollectionTypesRegistry(object):
             raise Exception("Cannot pre-determine structure for collection of type %s" % plugin_type)
 
         dataset_collection = model.DatasetCollection()
-        elements = [e for e in plugin_type_object.prototype_elements()]
-        dataset_collection.elements = elements
+        for e in plugin_type_object.prototype_elements():
+            e.collection = dataset_collection
         return dataset_collection
 
 
