@@ -13,7 +13,6 @@ import weakref
 from collections import OrderedDict
 from os.path import abspath
 
-from six import string_types
 from sqlalchemy.orm import object_session
 
 import galaxy.model
@@ -32,7 +31,7 @@ log = logging.getLogger(__name__)
 STATEMENTS = "__galaxy_statements__"  # this is the name of the property in a Datatype class where new metadata spec element Statements are stored
 
 
-class Statement(object):
+class Statement:
     """
     This class inserts its target into a list in the surrounding
     class.  the data.Data class has a metaclass which executes these
@@ -46,7 +45,7 @@ class Statement(object):
     def __call__(self, *args, **kwargs):
         # get the locals dictionary of the frame object one down in the call stack (i.e. the Datatype class calling MetadataElement)
         class_locals = sys._getframe(1).f_locals
-        # get and set '__galaxy_statments__' to an empty list if not in locals dict
+        # get and set '__galaxy_statements__' to an empty list if not in locals dict
         statements = class_locals.setdefault(STATEMENTS, [])
         # add Statement containing info to populate a MetadataElementSpec
         statements.append((self, args, kwargs))
@@ -57,7 +56,7 @@ class Statement(object):
             statement.target(element, *args, **kwargs)  # statement.target is MetadataElementSpec, element is a Datatype class
 
 
-class MetadataCollection(object):
+class MetadataCollection:
     """
     MetadataCollection is not a collection at all, but rather a proxy
     to the real metadata which is stored as a Dictionary. This class
@@ -130,7 +129,23 @@ class MetadataCollection(object):
             log.info("Attempted to delete invalid key '%s' from MetadataCollection" % name)
 
     def element_is_set(self, name):
-        return bool(self.parent._metadata.get(name, False))
+        """
+        check if the meta data with the given name is set, i.e.
+        - if the such a metadata actually exists and
+        - if its value differs from no_value
+
+        param name the name of the metadata element
+        return True if the value differes from the no_value
+            False if its equal of if no metadata with the name is specified
+        """
+        try:
+            meta_val = self.parent._metadata[name]
+        except KeyError:
+            log.debug("no metadata with name %s found" % (name))
+            return False
+
+        meta_spec = self.parent.metadata.spec[name]
+        return meta_val != meta_spec.no_value
 
     def get_metadata_parameter(self, name, **kwd):
         if name in self.spec:
@@ -157,11 +172,12 @@ class MetadataCollection(object):
     def from_JSON_dict(self, filename=None, path_rewriter=None, json_dict=None):
         dataset = self.parent
         if filename is not None:
-            log.debug('loading metadata from file for: %s %s' % (dataset.__class__.__name__, dataset.id))
-            JSONified_dict = json.load(open(filename))
+            log.debug('loading metadata from file for: {} {}'.format(dataset.__class__.__name__, dataset.id))
+            with open(filename) as fh:
+                JSONified_dict = json.load(fh)
         elif json_dict is not None:
-            log.debug('loading metadata from dict for: %s %s' % (dataset.__class__.__name__, dataset.id))
-            if isinstance(json_dict, string_types):
+            log.debug('loading metadata from dict for: {} {}'.format(dataset.__class__.__name__, dataset.id))
+            if isinstance(json_dict, str):
                 JSONified_dict = json.loads(json_dict)
             elif isinstance(json_dict, dict):
                 JSONified_dict = json_dict
@@ -199,7 +215,6 @@ class MetadataCollection(object):
             dataset.validated_state_message = JSONified_dict['__validated_state_message__']
 
     def to_JSON_dict(self, filename=None):
-        # galaxy.model.customtypes.json_encoder.encode()
         meta_dict = {}
         dataset_meta_dict = self.parent._metadata
         for name, spec in self.spec.items():
@@ -211,9 +226,11 @@ class MetadataCollection(object):
             meta_dict['__validated_state__'] = dataset_meta_dict['__validated_state__']
         if '__validated_state_message__' in dataset_meta_dict:
             meta_dict['__validated_state_message__'] = dataset_meta_dict['__validated_state_message__']
+        encoded_meta_dict = galaxy.model.custom_types.json_encoder.encode(meta_dict)
         if filename is None:
-            return json.dumps(meta_dict)
-        json.dump(meta_dict, open(filename, 'wt+'))
+            return encoded_meta_dict
+        with open(filename, 'wt+') as fh:
+            fh.write(encoded_meta_dict)
 
     def __getstate__(self):
         # cannot pickle a weakref item (self._parent), when
@@ -230,7 +247,7 @@ class MetadataSpecCollection(OrderedDict):
     """
 
     def __init__(self, *args, **kwds):
-        super(MetadataSpecCollection, self).__init__(*args, **kwds)
+        super().__init__(*args, **kwds)
 
     def append(self, item):
         self[item.name] = item
@@ -245,7 +262,7 @@ class MetadataSpecCollection(OrderedDict):
         return ', '.join(item.__str__() for item in self.values())
 
 
-class MetadataParameter(object):
+class MetadataParameter:
     def __init__(self, spec):
         self.spec = spec
 
@@ -275,7 +292,6 @@ class MetadataParameter(object):
         """
         Throw an exception if the value is invalid.
         """
-        pass
 
     def unwrap(self, form_value):
         """
@@ -304,7 +320,7 @@ class MetadataParameter(object):
         return value
 
 
-class MetadataElementSpec(object):
+class MetadataElementSpec:
     """
     Defines a metadata element and adds it to the metadata_spec (which
     is a MetadataSpecCollection) of datatype.
@@ -425,7 +441,7 @@ class DBKeyParameter(SelectParameter):
             values = kwd['trans'].app.genome_builds.get_genome_build_names(kwd['trans'])
         except KeyError:
             pass
-        return super(DBKeyParameter, self).get_field(value, context, other_values, values, **kwd)
+        return super().get_field(value, context, other_values, values, **kwd)
 
 
 class RangeParameter(SelectParameter):
@@ -524,12 +540,15 @@ class FileParameter(MetadataParameter):
             return None
         if isinstance(value, galaxy.model.MetadataFile) or isinstance(value, MetadataTempFile):
             return value
-        mf = session.query(galaxy.model.MetadataFile).get(value)
-        return mf
+        return session.query(galaxy.model.MetadataFile).get(value)
 
     def make_copy(self, value, target_context, source_context):
         value = self.wrap(value, object_session(target_context.parent))
-        if value:
+        target_dataset = target_context.parent.dataset
+        if value and target_dataset.object_store.exists(target_dataset):
+            # Only copy MetadataFile if the target dataset has been created in an object store.
+            # All current datatypes re-generate MetadataFile objects when setting metadata,
+            # so this would ultimately get overwritten anyway.
             new_value = galaxy.model.MetadataFile(dataset=target_context.parent, name=self.spec.name)
             object_session(target_context.parent).add(new_value)
             object_session(target_context.parent).flush()
@@ -540,7 +559,10 @@ class FileParameter(MetadataParameter):
     @classmethod
     def marshal(cls, value):
         if isinstance(value, galaxy.model.MetadataFile):
-            value = value.id
+            # We want to push value.id to the database, but need to skip this when no session is available,
+            # as in extended_metadata mode, so there we just accept MetadataFile.
+            # We will only serialize MetadataFile in this mode and not push to the database, so this is OK.
+            value = value.id or value
         return value
 
     def from_external_value(self, value, parent, path_rewriter=None):
@@ -597,7 +619,7 @@ class FileParameter(MetadataParameter):
 
 
 # This class is used when a database file connection is not available
-class MetadataTempFile(object):
+class MetadataTempFile:
     tmp_dir = 'database/tmp'  # this should be overwritten as necessary in calling scripts
 
     def __init__(self, **kwds):
@@ -631,12 +653,13 @@ class MetadataTempFile(object):
     @classmethod
     def cleanup_from_JSON_dict_filename(cls, filename):
         try:
-            for key, value in json.load(open(filename)).items():
-                if cls.is_JSONified_value(value):
-                    value = cls.from_JSON(value)
-                if isinstance(value, cls) and os.path.exists(value.file_name):
-                    log.debug('Cleaning up abandoned MetadataTempFile file: %s', value.file_name)
-                    os.unlink(value.file_name)
+            with open(filename) as fh:
+                for value in json.load(fh).values():
+                    if cls.is_JSONified_value(value):
+                        value = cls.from_JSON(value)
+                    if isinstance(value, cls) and os.path.exists(value.file_name):
+                        log.debug('Cleaning up abandoned MetadataTempFile file: %s', value.file_name)
+                        os.unlink(value.file_name)
         except Exception as e:
             log.debug('Failed to cleanup MetadataTempFile temp files from %s: %s', filename, unicodify(e))
 
