@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import datetime
 import errno
 import logging
@@ -61,7 +59,7 @@ def directory_hash_id(id):
     return [padded[i * 3:(i + 1) * 3] for i in range(len(padded) // 3)]
 
 
-class Dataset(object):
+class Dataset:
     states = Bunch(NEW='new',
                    UPLOAD='upload',
                    QUEUED='queued',
@@ -157,10 +155,10 @@ class Dataset(object):
         try:
             os.remove(self.data.file_name)
         except OSError as e:
-            log.critical('%s delete error %s' % (self.__class__.__name__, e))
+            log.critical('{} delete error {}'.format(self.__class__.__name__, e))
 
 
-class DatasetInstance(object):
+class DatasetInstance:
     """A base class for all 'dataset instances', HDAs, LDAs, etc"""
     states = Dataset.states
     permitted_actions = Dataset.permitted_actions
@@ -506,7 +504,7 @@ class LibraryDatasetDatasetAssociation(DatasetInstance):
         return template_list
 
 
-class LibraryDataset(object):
+class LibraryDataset:
     # This class acts as a proxy to the currently selected LDDA
     def __init__(self, folder=None, order_id=None, name=None, info=None, library_dataset_dataset_association=None, **kwd):
         self.folder = folder
@@ -752,7 +750,7 @@ def upgrade(migrate_engine):
                 changed_associations += 1
             # mark original Dataset as deleted and purged, it is no longer in use, but do not delete file_name contents
             dataset.deleted = True
-            dataset.external_filename = "Dataset was result of share before HDA, and has been replaced: %s mapped to Dataset %s" % (dataset.external_filename, guessed_dataset.id)
+            dataset.external_filename = "Dataset was result of share before HDA, and has been replaced: {} mapped to Dataset {}".format(dataset.external_filename, guessed_dataset.id)
             dataset.purged = True  # we don't really purge the file here, but we mark it as purged, since this dataset is now defunct
     context.flush()
     log.debug("%i items affected, and restored." % (changed_associations))
