@@ -1,7 +1,6 @@
 """
 Migration script to rename the sequencer information form type to external service information form
 """
-from __future__ import print_function
 
 import logging
 
@@ -17,7 +16,7 @@ def upgrade(migrate_engine):
     metadata.reflect()
     current_form_type = 'Sequencer Information Form'
     new_form_type = "External Service Information Form"
-    cmd = "update form_definition set type='%s' where type='%s'" % (new_form_type, current_form_type)
+    cmd = "update form_definition set type='{}' where type='{}'".format(new_form_type, current_form_type)
     migrate_engine.execute(cmd)
 
 
@@ -26,5 +25,5 @@ def downgrade(migrate_engine):
     metadata.reflect()
     new_form_type = 'Sequencer Information Form'
     current_form_type = "External Service Information Form"
-    cmd = "update form_definition set type='%s' where type='%s'" % (new_form_type, current_form_type)
+    cmd = "update form_definition set type='{}' where type='{}'".format(new_form_type, current_form_type)
     migrate_engine.execute(cmd)
