@@ -5,10 +5,13 @@ import os
 import shutil
 import tarfile
 import tempfile
-from json import dump, dumps, load
+from json import (
+    dump,
+    dumps,
+    load,
+)
 from uuid import uuid4
 
-import six
 from bdbag import bdbag_api as bdb
 from boltons.iterutils import remap
 from sqlalchemy.orm import eagerload_all
@@ -20,6 +23,7 @@ from galaxy.util import FILENAME_VALID_CHARS
 from galaxy.util import in_directory
 from galaxy.util.bunch import Bunch
 from galaxy.util.path import safe_walk
+from ..custom_types import json_encoder
 from ..item_attrs import add_item_annotation, get_item_annotation_str
 from ... import model
 
@@ -33,7 +37,7 @@ ATTRS_FILENAME_LIBRARIES = 'libraries_attrs.txt'
 GALAXY_EXPORT_VERSION = "2"
 
 
-class ImportOptions(object):
+class ImportOptions:
 
     def __init__(self, allow_edit=False, allow_library_creation=False, allow_dataset_object_edit=None):
         self.allow_edit = allow_edit
@@ -43,7 +47,7 @@ class ImportOptions(object):
         self.allow_dataset_object_edit = allow_dataset_object_edit
 
 
-class SessionlessContext(object):
+class SessionlessContext:
 
     def __init__(self):
         self.objects = []
@@ -65,8 +69,7 @@ class SessionlessContext(object):
         return Bunch(find=find)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ModelImportStore(object):
+class ModelImportStore(metaclass=abc.ABCMeta):
 
     def __init__(self, import_options=None, app=None, user=None, object_store=None):
         if object_store is None:
@@ -436,6 +439,8 @@ class ModelImportStore(object):
                                                          element=model.DatasetCollectionElement.UNINITIALIZED_ELEMENT,
                                                          element_index=element_attrs['element_index'],
                                                          element_identifier=element_attrs['element_identifier'])
+                    if 'encoded_id' in element_attrs:
+                        object_import_tracker.dces_by_key[element_attrs['encoded_id']] = dce
                     if 'hda' in element_attrs:
                         hda_attrs = element_attrs['hda']
                         if object_key in hda_attrs:
@@ -444,12 +449,12 @@ class ModelImportStore(object):
                             if hda_key in hdas_by_key:
                                 hda = hdas_by_key[hda_key]
                             else:
-                                raise KeyError("Failed to find exported hda with key [%s] of type [%s] in [%s]" % (hda_key, object_key, hdas_by_key))
+                                raise KeyError("Failed to find exported hda with key [{}] of type [{}] in [{}]".format(hda_key, object_key, hdas_by_key))
                         else:
                             hda_id = hda_attrs["id"]
                             hdas_by_id = object_import_tracker.hdas_by_id
                             if hda_id not in hdas_by_id:
-                                raise Exception("Failed to find HDA with id [%s] in [%s]" % (hda_id, hdas_by_id))
+                                raise Exception("Failed to find HDA with id [{}] in [{}]".format(hda_id, hdas_by_id))
                             hda = hdas_by_id[hda_id]
                         dce.hda = hda
                     elif 'child_collection' in element_attrs:
@@ -557,7 +562,7 @@ class ModelImportStore(object):
                 # attach to this node... unless we've already encountered another dataset
                 # copied from that jobs output... in that case we are going to cheat and
                 # say this dataset was copied from that one. It wasn't in the original Galaxy
-                # instance but I think it is find to pretend in order to create a DAG here.
+                # instance but I think it is fine to pretend in order to create a DAG here.
                 hda_copied_from_sinks = object_import_tracker.hda_copied_from_sinks
                 if copied_from_object_key in hda_copied_from_sinks:
                     hda.copied_from_history_dataset_association = object_import_tracker.hdas_by_key[hda_copied_from_sinks[copied_from_object_key]]
@@ -622,9 +627,15 @@ class ModelImportStore(object):
             if input_key in object_import_tracker.hdcas_by_key:
                 hdca = object_import_tracker.hdcas_by_key[input_key]
             if input_key in object_import_tracker.hdca_copied_from_sinks:
-                hdca = object_import_tracker.hdca_copied_from_sinks[input_key]
+                hdca = object_import_tracker.hdcas_by_key[object_import_tracker.hdca_copied_from_sinks[input_key]]
             return hdca
 
+        def _find_dce(input_key):
+            dce = None
+            if input_key in object_import_tracker.dces_by_key:
+                dce = object_import_tracker.dces_by_key[input_key]
+            return dce
+
         #
         # Create jobs.
         #
@@ -636,7 +647,7 @@ class ModelImportStore(object):
                 assert self.import_options.allow_edit
                 assert not self.sessionless
                 job = self.sa_session.query(model.Job).get(job_attrs["id"])
-                self._connect_job_io(job, job_attrs, _find_hda, _find_hdca)
+                self._connect_job_io(job, job_attrs, _find_hda, _find_hdca, _find_dce)
                 self._flush()
                 continue
 
@@ -674,12 +685,12 @@ class ModelImportStore(object):
             self._flush()
 
             # Connect jobs to input and output datasets.
-            params = self._normalize_job_parameters(imported_job, job_attrs, _find_hda, _find_hdca)
+            params = self._normalize_job_parameters(imported_job, job_attrs, _find_hda, _find_hdca, _find_dce)
             for name, value in params.items():
                 # Transform parameter values when necessary.
                 imported_job.add_parameter(name, dumps(value))
 
-            self._connect_job_io(imported_job, job_attrs, _find_hda, _find_hdca)
+            self._connect_job_io(imported_job, job_attrs, _find_hda, _find_hdca, _find_dce)
             self._flush()
 
             if object_key in job_attrs:
@@ -733,7 +744,7 @@ def _copied_from_object_key(copied_from_chain, objects_by_key):
     return copied_from_object_key
 
 
-class ObjectImportTracker(object):
+class ObjectImportTracker:
     """Keep track of new and existing imported objects.
 
     Needed to re-establish connections and such in multiple passes.
@@ -745,6 +756,8 @@ class ObjectImportTracker(object):
         self.hdas_by_id = {}
         self.hdcas_by_key = {}
         self.hdcas_by_id = {}
+        self.dces_by_key = {}
+        self.dces_by_id = {}
         self.lddas_by_key = {}
         self.hda_copied_from_sinks = {}
         self.hdca_copied_from_sinks = {}
@@ -816,7 +829,7 @@ class DirectoryImportModelStore1901(BaseDirectoryImportModelStore):
     object_key = 'hid'
 
     def __init__(self, archive_dir, **kwd):
-        super(DirectoryImportModelStore1901, self).__init__(**kwd)
+        super().__init__(**kwd)
         archive_dir = os.path.realpath(archive_dir)
 
         # Bioblend previous to 17.01 exported histories with an extra subdir.
@@ -828,7 +841,7 @@ class DirectoryImportModelStore1901(BaseDirectoryImportModelStore):
 
         self.archive_dir = archive_dir
 
-    def _connect_job_io(self, imported_job, job_attrs, _find_hda, _find_hdca):
+    def _connect_job_io(self, imported_job, job_attrs, _find_hda, _find_hdca, _find_dce):
         for output_key in job_attrs['output_datasets']:
             output_hda = _find_hda(output_key)
             if output_hda:
@@ -843,7 +856,7 @@ class DirectoryImportModelStore1901(BaseDirectoryImportModelStore):
                 if input_hda:
                     imported_job.add_input_dataset(input_name, input_hda)
 
-    def _normalize_job_parameters(self, imported_job, job_attrs, _find_hda, _find_hdca):
+    def _normalize_job_parameters(self, imported_job, job_attrs, _find_hda, _find_hdca, _find_dce):
         def remap_objects(p, k, obj):
             if isinstance(obj, dict) and obj.get('__HistoryDatasetAssociation__', False):
                 imported_hda = _find_hda(obj[self.object_key])
@@ -865,7 +878,7 @@ class DirectoryImportModelStoreLatest(BaseDirectoryImportModelStore):
     object_key = 'encoded_id'
 
     def __init__(self, archive_dir, **kwd):
-        super(DirectoryImportModelStoreLatest, self).__init__(**kwd)
+        super().__init__(**kwd)
         archive_dir = os.path.realpath(archive_dir)
         self.archive_dir = archive_dir
         if self.defines_new_history():
@@ -873,7 +886,7 @@ class DirectoryImportModelStoreLatest(BaseDirectoryImportModelStore):
         else:
             self.import_history_encoded_id = None
 
-    def _connect_job_io(self, imported_job, job_attrs, _find_hda, _find_hdca):
+    def _connect_job_io(self, imported_job, job_attrs, _find_hda, _find_hdca, _find_dce):
 
         if 'input_dataset_mapping' in job_attrs:
             for input_name, input_keys in job_attrs['input_dataset_mapping'].items():
@@ -891,6 +904,14 @@ class DirectoryImportModelStoreLatest(BaseDirectoryImportModelStore):
                     if input_hdca:
                         imported_job.add_input_dataset_collection(input_name, input_hdca)
 
+        if 'input_dataset_collection_element_mapping' in job_attrs:
+            for input_name, input_keys in job_attrs['input_dataset_collection_element_mapping'].items():
+                input_keys = input_keys or []
+                for input_key in input_keys:
+                    input_dce = _find_dce(input_key)
+                    if input_dce:
+                        imported_job.add_input_dataset_collection_element(input_name, input_dce)
+
         if 'output_dataset_mapping' in job_attrs:
             for output_name, output_keys in job_attrs['output_dataset_mapping'].items():
                 output_keys = output_keys or []
@@ -913,9 +934,9 @@ class DirectoryImportModelStoreLatest(BaseDirectoryImportModelStore):
     def trust_hid(self, obj_attrs):
         return self.import_history_encoded_id and obj_attrs.get("history_encoded_id") == self.import_history_encoded_id
 
-    def _normalize_job_parameters(self, imported_job, job_attrs, _find_hda, _find_hdca):
+    def _normalize_job_parameters(self, imported_job, job_attrs, _find_hda, _find_hdca, _find_dce):
         def remap_objects(p, k, obj):
-            if isinstance(obj, dict) and "src" in obj and obj["src"] in ["hda", "hdca"]:
+            if isinstance(obj, dict) and "src" in obj and obj["src"] in ["hda", "hdca", "dce"]:
                 if obj["src"] == "hda":
                     imported_hda = _find_hda(obj["id"])
                     if imported_hda:
@@ -928,6 +949,12 @@ class DirectoryImportModelStoreLatest(BaseDirectoryImportModelStore):
                         new_id = imported_hdca.id
                     else:
                         new_id = None
+                elif obj["src"] == "dce":
+                    imported_dce = _find_dce(obj["id"])
+                    if imported_dce:
+                        new_id = imported_dce.id
+                    else:
+                        new_id = None
                 else:
                     raise NotImplementedError()
                 new_obj = obj.copy()
@@ -949,11 +976,10 @@ class BagArchiveImportModelStore(DirectoryImportModelStoreLatest):
         # Why this line though...?
         archive_dir = os.path.join(archive_dir, os.listdir(archive_dir)[0])
         bdb.revert_bag(archive_dir)
-        super(BagArchiveImportModelStore, self).__init__(archive_dir, **kwd)
+        super().__init__(archive_dir, **kwd)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ModelExportStore(object):
+class ModelExportStore(metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def export_history(self, history, include_hidden=False, include_deleted=False):
@@ -1197,20 +1223,23 @@ class DirectoryModelExportStore(ModelExportStore):
             else:
                 provenance_attrs.append(dataset)
 
+        def to_json(attributes):
+            return json_encoder.encode([a.serialize(self.security, self.serialization_options) for a in attributes])
+
         datasets_attrs_filename = os.path.join(export_directory, ATTRS_FILENAME_DATASETS)
         with open(datasets_attrs_filename, 'w') as datasets_attrs_out:
-            dump(list(map(lambda d: d.serialize(self.security, self.serialization_options), datasets_attrs)), datasets_attrs_out)
+            datasets_attrs_out.write(to_json(datasets_attrs))
 
         with open(datasets_attrs_filename + ".provenance", 'w') as provenance_attrs_out:
-            dump(list(map(lambda d: d.serialize(self.security, self.serialization_options), provenance_attrs)), provenance_attrs_out)
+            provenance_attrs_out.write(to_json(provenance_attrs))
 
         libraries_attrs_filename = os.path.join(export_directory, ATTRS_FILENAME_LIBRARIES)
-        with open(libraries_attrs_filename, 'w') as librariess_attrs_out:
-            dump(list(map(lambda d: d.serialize(self.security, self.serialization_options), self.included_libraries)), librariess_attrs_out)
+        with open(libraries_attrs_filename, 'w') as libraries_attrs_out:
+            libraries_attrs_out.write(to_json(self.included_libraries))
 
         collections_attrs_filename = os.path.join(export_directory, ATTRS_FILENAME_COLLECTIONS)
         with open(collections_attrs_filename, 'w') as collections_attrs_out:
-            dump(list(map(lambda d: d.serialize(self.security, self.serialization_options), self.collections_attrs)), collections_attrs_out)
+            collections_attrs_out.write(to_json(self.collections_attrs))
 
         #
         # Write jobs attributes file.
@@ -1265,6 +1294,7 @@ class DirectoryModelExportStore(ModelExportStore):
             input_dataset_mapping = {}
             output_dataset_mapping = {}
             input_dataset_collection_mapping = {}
+            input_dataset_collection_element_mapping = {}
             output_dataset_collection_mapping = {}
             implicit_output_dataset_collection_mapping = {}
 
@@ -1295,6 +1325,14 @@ class DirectoryModelExportStore(ModelExportStore):
 
                     input_dataset_collection_mapping[name].append(self.exported_key(assoc.dataset_collection))
 
+            for assoc in job.input_dataset_collection_elements:
+                if assoc.dataset_collection_element:
+                    name = assoc.name
+                    if name not in input_dataset_collection_element_mapping:
+                        input_dataset_collection_element_mapping[name] = []
+
+                    input_dataset_collection_element_mapping[name].append(self.exported_key(assoc.dataset_collection_element))
+
             for assoc in job.output_dataset_collection_instances:
                 # Optional data outputs will not have a dataset.
                 if assoc.dataset_collection_instance:
@@ -1315,6 +1353,7 @@ class DirectoryModelExportStore(ModelExportStore):
 
             job_attrs['input_dataset_mapping'] = input_dataset_mapping
             job_attrs['input_dataset_collection_mapping'] = input_dataset_collection_mapping
+            job_attrs['input_dataset_collection_element_mapping'] = input_dataset_collection_element_mapping
             job_attrs['output_dataset_mapping'] = output_dataset_mapping
             job_attrs['output_dataset_collection_mapping'] = output_dataset_collection_mapping
             job_attrs['implicit_output_dataset_collection_mapping'] = implicit_output_dataset_collection_mapping
@@ -1336,11 +1375,11 @@ class DirectoryModelExportStore(ModelExportStore):
 
         jobs_attrs_filename = os.path.join(export_directory, ATTRS_FILENAME_JOBS)
         with open(jobs_attrs_filename, 'w') as jobs_attrs_out:
-            dump(jobs_attrs, jobs_attrs_out)
+            jobs_attrs_out.write(json_encoder.encode(jobs_attrs))
 
         icjs_attrs_filename = os.path.join(export_directory, ATTRS_FILENAME_IMPLICIT_COLLECTION_JOBS)
         with open(icjs_attrs_filename, 'w') as icjs_attrs_out:
-            dump(icjs_attrs, icjs_attrs_out)
+            icjs_attrs_out.write(json_encoder.encode(icjs_attrs))
 
         export_attrs_filename = os.path.join(export_directory, ATTRS_FILENAME_EXPORT)
         with open(export_attrs_filename, 'w') as export_attrs_out:
@@ -1360,10 +1399,10 @@ class TarModelExportStore(DirectoryModelExportStore):
         self.gzip = gzip
         self.out_file = out_file
         temp_output_dir = tempfile.mkdtemp()
-        super(TarModelExportStore, self).__init__(temp_output_dir, **kwds)
+        super().__init__(temp_output_dir, **kwds)
 
     def _finalize(self):
-        super(TarModelExportStore, self)._finalize()
+        super()._finalize()
         tar_export_directory(self.export_directory, self.out_file, self.gzip)
         shutil.rmtree(self.export_directory)
 
@@ -1372,10 +1411,10 @@ class BagDirectoryModelExportStore(DirectoryModelExportStore):
 
     def __init__(self, out_directory, **kwds):
         self.out_directory = out_directory
-        super(BagDirectoryModelExportStore, self).__init__(out_directory, **kwds)
+        super().__init__(out_directory, **kwds)
 
     def _finalize(self):
-        super(BagDirectoryModelExportStore, self)._finalize()
+        super()._finalize()
         bdb.make_bag(self.out_directory)
 
 
@@ -1386,10 +1425,10 @@ class BagArchiveModelExportStore(BagDirectoryModelExportStore):
         self.bag_archiver = bag_archiver
         self.out_file = out_file
         temp_output_dir = tempfile.mkdtemp()
-        super(BagArchiveModelExportStore, self).__init__(temp_output_dir, **kwds)
+        super().__init__(temp_output_dir, **kwds)
 
     def _finalize(self):
-        super(BagArchiveModelExportStore, self)._finalize()
+        super()._finalize()
         rval = bdb.archive_bag(self.export_directory, self.bag_archiver)
         shutil.move(rval, self.out_file)
         shutil.rmtree(self.export_directory)
@@ -1410,7 +1449,7 @@ def get_export_dataset_filename(name, ext, hid):
     Builds a filename for a dataset using its name an extension.
     """
     base = ''.join(c in FILENAME_VALID_CHARS and c or '_' for c in name)
-    return base + "_%s.%s" % (hid, ext)
+    return base + "_{}.{}".format(hid, ext)
 
 
 def imported_store_for_metadata(directory, object_store=None):
