@@ -13,7 +13,6 @@ from collections import (
     OrderedDict
 )
 
-import six
 
 import galaxy.model
 from galaxy import util
@@ -31,8 +30,7 @@ log = logging.getLogger(__name__)
 UNSET = object()
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ModelPersistenceContext(object):
+class ModelPersistenceContext(metaclass=abc.ABCMeta):
     """Class for creating datasets while finding files.
 
     This class implement the create_dataset method that takes care of populating metadata
@@ -46,7 +44,8 @@ class ModelPersistenceContext(object):
         visible,
         dbkey,
         name,
-        filename,
+        filename=None,
+        extra_files=None,
         metadata_source_name=None,
         info=None,
         library_folder=None,
@@ -54,12 +53,17 @@ class ModelPersistenceContext(object):
         primary_data=None,
         init_from=None,
         dataset_attributes=None,
-        tag_list=[],
-        sources=[],
-        hashes=[],
+        tag_list=None,
+        sources=None,
+        hashes=None,
         created_from_basename=None,
         final_job_state='ok',
     ):
+        tag_list = tag_list or []
+        sources = sources or []
+        hashes = hashes or []
+        dataset_attributes = dataset_attributes or {}
+
         sa_session = self.sa_session
 
         # You can initialize a dataset or initialize from a dataset but not both.
@@ -123,19 +127,32 @@ class ModelPersistenceContext(object):
         if created_from_basename is not None:
             primary_data.created_from_basename = created_from_basename
 
-        self.flush()
-
+        has_flushed = False
         if tag_list:
+            # If we have a tag we need a primary id, so need to flush here
+            # TODO: eliminate creating tag associations within create dataset
+            # We can do this incrementally by not passing in a tag list.
+            self.flush()
+            has_flushed = True
             self.tag_handler.add_tags_from_list(self.job.user, primary_data, tag_list)
 
         # Move data from temp location to dataset location
-        if not link_data:
-            self.object_store.update_from_file(primary_data.dataset, file_name=filename, create=True)
-        else:
-            primary_data.link_to(filename)
+        if filename:
+            # TODO: eliminate this, should happen outside of create_dataset so that we don't need to flush
+            if not has_flushed:
+                self.flush()
+                has_flushed = True
+            if not link_data:
+                self.object_store.update_from_file(primary_data.dataset, file_name=filename, create=True)
+            else:
+                primary_data.link_to(filename)
+            if extra_files:
+                persist_extra_files(self.object_store, extra_files, primary_data)
+                primary_data.set_size()
+            else:
+                # We are sure there are no extra files, so optimize things that follow by settting total size also.
+                primary_data.set_size(no_extra_files=True)
 
-        # We are sure there are no extra files, so optimize things that follow by settting total size also.
-        primary_data.set_size(no_extra_files=True)
         # If match specified a name use otherwise generate one from
         # designation.
         primary_data.name = name
@@ -155,38 +172,44 @@ class ModelPersistenceContext(object):
         if info is not None:
             primary_data.info = info
 
-        # add tool/metadata provided information
-        dataset_attributes = dataset_attributes or {}
-        if dataset_attributes:
-            # TODO: discover_files should produce a match that encorporates this -
-            # would simplify ToolProvidedMetadata interface and eliminate this
-            # crap path.
-            dataset_att_by_name = dict(ext='extension')
-            for att_set in ['name', 'info', 'ext', 'dbkey']:
-                dataset_att_name = dataset_att_by_name.get(att_set, att_set)
-                setattr(primary_data, dataset_att_name, dataset_attributes.get(att_set, getattr(primary_data, dataset_att_name)))
-
-        try:
-            metadata_dict = dataset_attributes.get('metadata', None)
-            if metadata_dict:
-                if "dbkey" in dataset_attributes:
-                    metadata_dict["dbkey"] = dataset_attributes["dbkey"]
-                # branch tested with tool_provided_metadata_3 / tool_provided_metadata_10
-                primary_data.metadata.from_JSON_dict(json_dict=metadata_dict)
-            else:
-                primary_data.set_meta()
-        except Exception:
-            if primary_data.state == galaxy.model.HistoryDatasetAssociation.states.OK:
-                primary_data.state = galaxy.model.HistoryDatasetAssociation.states.FAILED_METADATA
-            log.exception("Exception occured while setting metdata")
-
-        try:
-            primary_data.set_peek()
-        except Exception:
-            log.exception("Exception occured while setting dataset peek")
+        if filename:
+            self.set_datasets_metadata(datasets=[primary_data], datasets_attributes=[dataset_attributes])
 
         return primary_data
 
+    @staticmethod
+    def set_datasets_metadata(datasets, datasets_attributes=None):
+        datasets_attributes = datasets_attributes or [{} for _ in datasets]
+        for primary_data, dataset_attributes in zip(datasets, datasets_attributes):
+            # add tool/metadata provided information
+            if dataset_attributes:
+                # TODO: discover_files should produce a match that encorporates this -
+                # would simplify ToolProvidedMetadata interface and eliminate this
+                # crap path.
+                dataset_att_by_name = dict(ext='extension')
+                for att_set in ['name', 'info', 'ext', 'dbkey']:
+                    dataset_att_name = dataset_att_by_name.get(att_set, att_set)
+                    setattr(primary_data, dataset_att_name, dataset_attributes.get(att_set, getattr(primary_data, dataset_att_name)))
+
+            try:
+                metadata_dict = dataset_attributes.get('metadata', None)
+                if metadata_dict:
+                    if "dbkey" in dataset_attributes:
+                        metadata_dict["dbkey"] = dataset_attributes["dbkey"]
+                    # branch tested with tool_provided_metadata_3 / tool_provided_metadata_10
+                    primary_data.metadata.from_JSON_dict(json_dict=metadata_dict)
+                else:
+                    primary_data.set_meta()
+            except Exception:
+                if primary_data.state == galaxy.model.HistoryDatasetAssociation.states.OK:
+                    primary_data.state = galaxy.model.HistoryDatasetAssociation.states.FAILED_METADATA
+                log.exception("Exception occured while setting metdata")
+
+            try:
+                primary_data.set_peek()
+            except Exception:
+                log.exception("Exception occured while setting dataset peek")
+
     def populate_collection_elements(self, collection, root_collection_builder, filenames, name=None, metadata_source_name=None, final_job_state='ok'):
         # TODO: allow configurable sorting.
         #    <sort by="lexical" /> <!-- default -->
@@ -196,7 +219,7 @@ class ModelPersistenceContext(object):
         if name is None:
             name = "unnamed output"
 
-        element_datasets = []
+        element_datasets = {'element_identifiers': [], 'datasets': [], 'tag_lists': [], 'paths': [], 'extra_files': []}
         for filename, discovered_file in filenames.items():
             create_dataset_timer = ExecutionTimer()
             fields_match = discovered_file.match
@@ -207,6 +230,7 @@ class ModelPersistenceContext(object):
             visible = fields_match.visible
             ext = fields_match.ext
             dbkey = fields_match.dbkey
+            extra_files = fields_match.extra_files
             # galaxy.tools.parser.output_collection_def.INPUT_DBKEY_TOKEN
             if dbkey == "__input__":
                 dbkey = self.input_dbkey
@@ -215,7 +239,6 @@ class ModelPersistenceContext(object):
             dataset_name = fields_match.name or designation
 
             link_data = discovered_file.match.link_data
-            tag_list = discovered_file.match.tag_list
 
             sources = discovered_file.match.sources
             hashes = discovered_file.match.hashes
@@ -227,10 +250,8 @@ class ModelPersistenceContext(object):
                 visible=visible,
                 dbkey=dbkey,
                 name=dataset_name,
-                filename=filename,
                 metadata_source_name=metadata_source_name,
                 link_data=link_data,
-                tag_list=tag_list,
                 sources=sources,
                 hashes=hashes,
                 created_from_basename=created_from_basename,
@@ -244,18 +265,14 @@ class ModelPersistenceContext(object):
                 name,
                 create_dataset_timer,
             )
-            element_datasets.append((element_identifiers, dataset))
+            element_datasets['element_identifiers'].append(element_identifiers)
+            element_datasets['extra_files'].append(extra_files)
+            element_datasets['datasets'].append(dataset)
+            element_datasets['tag_lists'].append(discovered_file.match.tag_list)
+            element_datasets['paths'].append(filename)
 
-        add_datasets_timer = ExecutionTimer()
-        self.add_datasets_to_history([d for (ei, d) in element_datasets])
-        log.debug(
-            "(%s) Add dynamic collection datasets to history for output [%s] %s",
-            self.job_id(),
-            name,
-            add_datasets_timer,
-        )
-
-        for (element_identifiers, dataset) in element_datasets:
+        self.add_tags_to_datasets(datasets=element_datasets['datasets'], tag_lists=element_datasets['tag_lists'])
+        for (element_identifiers, dataset) in zip(element_datasets['element_identifiers'], element_datasets['datasets']):
             current_builder = root_collection_builder
             for element_identifier in element_identifiers[:-1]:
                 current_builder = current_builder.get_level(element_identifier)
@@ -263,10 +280,38 @@ class ModelPersistenceContext(object):
 
             # Associate new dataset with job
             element_identifier_str = ":".join(element_identifiers)
-            association_name = '__new_primary_file_%s|%s__' % (name, element_identifier_str)
+            association_name = '__new_primary_file_{}|{}__'.format(name, element_identifier_str)
             self.add_output_dataset_association(association_name, dataset)
 
-        self.flush()
+        self.update_object_store_with_datasets(datasets=element_datasets['datasets'], paths=element_datasets['paths'], extra_files=element_datasets['extra_files'])
+        add_datasets_timer = ExecutionTimer()
+        self.add_datasets_to_history(element_datasets['datasets'])
+        log.debug(
+            "(%s) Add dynamic collection datasets to history for output [%s] %s",
+            self.job_id(),
+            name,
+            add_datasets_timer,
+        )
+        self.set_datasets_metadata(datasets=element_datasets['datasets'])
+
+    def add_tags_to_datasets(self, datasets, tag_lists):
+        if any(tag_lists):
+            # This works around SessionlessModelPersistenceContext not implementing a tag handler ...
+            # that's not better or worse than what we previously did in create_datasets
+            # TDOD: implement that or figure out why it is not implemented and find a better solution.
+            # Could it be that SessionlessModelPersistenceContext doesn't support tags?
+            tag_session = self.tag_handler.create_tag_handler_session()
+            for dataset, tags in zip(datasets, tag_lists):
+                tag_session.add_tags_from_list(self.job.user, dataset, tags, flush=False)
+
+    def update_object_store_with_datasets(self, datasets, paths, extra_files):
+        for dataset, path, extra_file in zip(datasets, paths, extra_files):
+            self.object_store.update_from_file(dataset.dataset, file_name=path, create=True)
+            if extra_file:
+                persist_extra_files(self.object_store, extra_files, dataset)
+                dataset.set_size()
+            else:
+                dataset.set_size(no_extra_files=True)
 
     @abc.abstractproperty
     def tag_handler(self):
@@ -304,8 +349,7 @@ class ModelPersistenceContext(object):
         """If database bound, flush the persisted objects to ensure IDs."""
 
 
-@six.add_metaclass(abc.ABCMeta)
-class PermissionProvider(object):
+class PermissionProvider(metaclass=abc.ABCMeta):
     """Interface for working with permissions while importing datasets with ModelPersistenceContext."""
 
     @property
@@ -332,8 +376,7 @@ class UnusedPermissionProvider(PermissionProvider):
         return
 
 
-@six.add_metaclass(abc.ABCMeta)
-class MetadataSourceProvider(object):
+class MetadataSourceProvider(metaclass=abc.ABCMeta):
     """Interface for working with fetching input dataset metadata with ModelPersistenceContext."""
 
     @abc.abstractmethod
@@ -413,6 +456,24 @@ class SessionlessModelPersistenceContext(ModelPersistenceContext):
         """No-op, no job context to persist this association for."""
 
 
+def persist_extra_files(object_store, src_extra_files_path, primary_data):
+    if src_extra_files_path and os.path.exists(src_extra_files_path):
+        primary_data.dataset.create_extra_files_path()
+        target_extra_files_path = primary_data.extra_files_path
+        for root, dirs, files in os.walk(src_extra_files_path):
+            extra_dir = os.path.join(target_extra_files_path, root.replace(src_extra_files_path, '', 1).lstrip(os.path.sep))
+            extra_dir = os.path.normpath(extra_dir)
+            for f in files:
+                object_store.update_from_file(
+                    primary_data.dataset,
+                    extra_dir=extra_dir,
+                    alt_name=f,
+                    file_name=os.path.join(root, f),
+                    create=True,
+                    preserve_symlinks=True
+                )
+
+
 def persist_target_to_export_store(target_dict, export_store, object_store, work_directory):
     replace_request_syntax_sugar(target_dict)
     model_persistence_context = SessionlessModelPersistenceContext(object_store, export_store, work_directory)
@@ -502,7 +563,10 @@ def persist_elements_to_folder(model_persistence_context, elements, library_fold
             sources = fields_match.sources
             hashes = fields_match.hashes
             created_from_basename = fields_match.created_from_basename
-
+            state = 'ok'
+            if hasattr(discovered_file, "error_message"):
+                info = discovered_file.error_message
+                state = "error"
             model_persistence_context.create_dataset(
                 ext=ext,
                 designation=designation,
@@ -516,6 +580,7 @@ def persist_elements_to_folder(model_persistence_context, elements, library_fold
                 sources=sources,
                 hashes=hashes,
                 created_from_basename=created_from_basename,
+                final_job_state=state,
             )
 
 
@@ -547,7 +612,11 @@ def persist_hdas(elements, model_persistence_context, final_job_state='ok'):
                 sources = fields_match.sources
                 hashes = fields_match.hashes
                 created_from_basename = fields_match.created_from_basename
-
+                extra_files = fields_match.extra_files
+                state = final_job_state
+                if hasattr(discovered_file, "error_message"):
+                    state = "error"
+                    info = discovered_file.error_message
                 dataset = model_persistence_context.create_dataset(
                     ext=ext,
                     designation=designation,
@@ -555,13 +624,14 @@ def persist_hdas(elements, model_persistence_context, final_job_state='ok'):
                     dbkey=dbkey,
                     name=name,
                     filename=discovered_file.path,
+                    extra_files=extra_files,
                     info=info,
                     link_data=link_data,
                     primary_data=primary_dataset,
                     sources=sources,
                     hashes=hashes,
                     created_from_basename=created_from_basename,
-                    final_job_state=final_job_state,
+                    final_job_state=state,
                 )
                 if not hda_id:
                     datasets.append(dataset)
@@ -626,19 +696,26 @@ def replace_request_syntax_sugar(obj):
 
 
 DiscoveredFile = namedtuple('DiscoveredFile', ['path', 'collector', 'match'])
+DiscoveredFileError = namedtuple('DiscoveredFileError', ['error_message', 'collector', 'match'])
+DiscoveredFileError.path = None
 
 
 def discovered_file_for_element(dataset, job_working_directory, parent_identifiers=[], collector=None):
     target_directory = discover_target_directory(getattr(collector, "directory", None), job_working_directory)
-    filename = dataset["filename"]
-    # handle link_data_only here, verify filename is in directory if not linking...
-    if not dataset.get("link_data_only"):
-        path = os.path.join(target_directory, filename)
-        if not util.in_directory(path, target_directory):
-            raise Exception("Problem with tool configuration, attempting to pull in datasets from outside working directory.")
+    filename = dataset.get("filename")
+    error_message = dataset.get("error_message")
+    if error_message is None:
+        # handle link_data_only here, verify filename is in directory if not linking...
+        if not dataset.get("link_data_only"):
+            path = os.path.join(target_directory, filename)
+            if not util.in_directory(path, target_directory):
+                raise Exception("Problem with tool configuration, attempting to pull in datasets from outside working directory.")
+        else:
+            path = filename
+        return DiscoveredFile(path, collector, JsonCollectedDatasetMatch(dataset, collector, filename, path=path, parent_identifiers=parent_identifiers))
     else:
-        path = filename
-    return DiscoveredFile(path, collector, JsonCollectedDatasetMatch(dataset, collector, filename, path=path, parent_identifiers=parent_identifiers))
+        assert "error_message" in dataset
+        return DiscoveredFileError(dataset['error_message'], collector, JsonCollectedDatasetMatch(dataset, collector, None, parent_identifiers=parent_identifiers))
 
 
 def discover_target_directory(dir_name, job_working_directory):
@@ -651,7 +728,7 @@ def discover_target_directory(dir_name, job_working_directory):
         return job_working_directory
 
 
-class JsonCollectedDatasetMatch(object):
+class JsonCollectedDatasetMatch:
 
     def __init__(self, as_dict, collector, filename, path=None, parent_identifiers=[]):
         self.as_dict = as_dict
@@ -737,10 +814,14 @@ class JsonCollectedDatasetMatch(object):
     def created_from_basename(self):
         return self.as_dict.get("created_from_basename")
 
+    @property
+    def extra_files(self):
+        return self.as_dict.get("extra_files")
+
 
 class RegexCollectedDatasetMatch(JsonCollectedDatasetMatch):
 
     def __init__(self, re_match, collector, filename, path=None):
-        super(RegexCollectedDatasetMatch, self).__init__(
+        super().__init__(
             re_match.groupdict(), collector, filename, path=path
         )
