@@ -9,7 +9,7 @@ from galaxy.util.tool_shed import common_util
 log = logging.getLogger(__name__)
 
 
-class ToolShedRepository(object):
+class ToolShedRepository:
     dict_collection_visible_keys = ['id', 'tool_shed', 'name', 'owner', 'installed_changeset_revision', 'changeset_revision', 'ctx_rev', 'includes_datatypes',
                                     'tool_shed_status', 'deleted', 'uninstalled', 'dist_to_shed', 'status', 'error_message', 'description']
     dict_element_visible_keys = ['id', 'tool_shed', 'name', 'owner', 'installed_changeset_revision', 'changeset_revision', 'ctx_rev', 'includes_datatypes',
@@ -469,20 +469,20 @@ class ToolShedRepository(object):
         return False
 
 
-class RepositoryRepositoryDependencyAssociation(object):
+class RepositoryRepositoryDependencyAssociation:
 
     def __init__(self, tool_shed_repository_id=None, repository_dependency_id=None):
         self.tool_shed_repository_id = tool_shed_repository_id
         self.repository_dependency_id = repository_dependency_id
 
 
-class RepositoryDependency(object):
+class RepositoryDependency:
 
     def __init__(self, tool_shed_repository_id=None):
         self.tool_shed_repository_id = tool_shed_repository_id
 
 
-class ToolDependency(object):
+class ToolDependency:
     installation_status = Bunch(NEVER_INSTALLED='Never installed',
                                 INSTALLING='Installing',
                                 INSTALLED='Installed',
@@ -560,7 +560,7 @@ class ToolVersion(Dictifiable):
         self.tool_shed_repository = tool_shed_repository
 
     def to_dict(self, view='element'):
-        rval = super(ToolVersion, self).to_dict(view=view)
+        rval = super().to_dict(view=view)
         rval['tool_name'] = self.tool_id
         for a in self.parent_tool_association:
             rval['parent_tool_id'] = a.parent_id
@@ -569,7 +569,7 @@ class ToolVersion(Dictifiable):
         return rval
 
 
-class ToolVersionAssociation(object):
+class ToolVersionAssociation:
 
     def __init__(self, id=None, tool_id=None, parent_id=None):
         self.id = id
@@ -577,7 +577,7 @@ class ToolVersionAssociation(object):
         self.parent_id = parent_id
 
 
-class MigrateTools(object):
+class MigrateTools:
 
     def __init__(self, repository_id=None, repository_path=None, version=None):
         self.repository_id = repository_id
